@@ -97,7 +97,7 @@ void function_list_prepare(void)
 		fclose( apifile );
 	}
 	else {
-		g_print("WARNING: Could not open php-gphpedit.api file\n");
+		g_print(_("WARNING: Could not open php-gphpedit.api file\n"));
 	}
 }
 
@@ -233,7 +233,7 @@ GString *get_css_completion_list(GtkWidget *scintilla, gint wordStart, gint word
 {
 	GString *completion_list;
 	gchar *buffer = NULL;
-	guint length;
+	gint length;
 	guint n;
 
 	buffer = gtk_scintilla_get_text_range (GTK_SCINTILLA(scintilla), wordStart, wordEnd, &length);
@@ -264,7 +264,7 @@ GString *get_sql_completion_list(GtkWidget *scintilla, gint wordStart, gint word
 {
 	GString *completion_list;
 	gchar *buffer = NULL;
-	guint length;
+	gint length;
 	guint n;
 
 	buffer = gtk_scintilla_get_text_range (GTK_SCINTILLA(scintilla), wordStart, wordEnd, &length);
