@@ -127,7 +127,7 @@ void classbrowser_filelist_add(gchar *filename)
 		filename += 6;
 	}
 
-	if (!classbrowser_filelist_find(filename) && is_php_file(filename)) {
+	if (!classbrowser_filelist_find(filename) && is_php_file_from_filename(filename)) {
 		file = g_malloc(sizeof(ClassBrowserFile));
 		file->filename = strip_double_slashes(filename);
 		file->accessible = TRUE;
@@ -191,7 +191,7 @@ void classbrowser_dirlist_add(gchar *dir)
 				if (g_file_test(fullfilename->str, G_FILE_TEST_IS_DIR)) {
 					//classbrowser_dirlist_add(fullfilename->str);
 				}
-				else if (is_php_file(fullfilename->str)){
+				else if (is_php_file_from_filename(fullfilename->str)){
 					classbrowser_filelist_add(fullfilename->str);
 				}
 				g_string_free(fullfilename, TRUE);
@@ -207,6 +207,19 @@ void classbrowser_dirlist_add(gchar *dir)
 	dirlist = g_slist_append(dirlist, g_strdup(dir));
 }
 
+void classbrowser_dirlist_add_shared_source()
+{
+	gchar **shared_source_locations;
+	gint i;
+
+	shared_source_locations = g_strsplit(preferences.shared_source_location,",",-1);
+
+	for (i = 0; shared_source_locations[i] != NULL; i++) {
+		classbrowser_dirlist_add(shared_source_locations[i]);
+	}
+			
+	g_strfreev(shared_source_locations);
+}
 
 gboolean classbrowser_file_accessible(gchar *filename)
 {
@@ -278,15 +291,13 @@ void classbrowser_start_update(void)
 	for(li = functionlist; li!= NULL; li = g_slist_next(li)) {
 		function = li->data;
 		if (function) {
-			function->remove
-			= TRUE;
+			function->remove = TRUE;
 		}
 	}
 	for(li = classlist; li!= NULL; li = g_slist_next(li)) {
 		class = li->data;
 		if (class) {
-			class->remove
-						= TRUE;
+			class->remove = TRUE;
 		}
 	}
 }
@@ -640,6 +651,7 @@ void classbrowser_update(void)
 	}
 	classbrowser_filelist_clear();
 	classbrowser_dirlist_clear();
+	classbrowser_dirlist_add_shared_source();
 
 	// iterate open files
 	for(li = editors; li!= NULL; li = g_slist_next(li)) {
@@ -771,7 +783,7 @@ void classbrowser_update_selected_label(gchar *filename, gint line)
 
 	new_label = get_differing_part(filenames, filename);
 	if (new_label) {
-		new_label = g_string_prepend(new_label, "FILE: ");
+		new_label = g_string_prepend(new_label, _("FILE: "));
 		g_string_append_printf(new_label, "(%d)", line);
 		gtk_label_set_text(GTK_LABEL(main_window.treeviewlabel), new_label->str);
 		g_string_free(new_label, TRUE);
