@@ -24,7 +24,6 @@
    The GNU General Public License is contained in the file COPYING.*/
 
 #include "config.h"
-#include <glib/gi18n.h>
 #include "find_replace.h"
 #include "main_window.h"
 
@@ -84,7 +83,7 @@ void find_clicked(GtkButton *button, gpointer data)
 
 	if (result == -1) {
 		// Show message saying could not be found.
-		gnome_dialog_run_and_close(GNOME_DIALOG(gnome_ok_dialog(_("Text not found."))));
+		gnome_dialog_run_and_close(GNOME_DIALOG(gnome_ok_dialog(g_strdup_printf(_("The text \"%s\" was not found."), text))));
 	}
 	else {
 		if (start_found == last_found) {
@@ -119,7 +118,7 @@ void find_create(void)
 	find_dialog.radiobutton5_group = NULL;
 
 	find_dialog.window1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_position (GTK_WINDOW(find_dialog.window1),GTK_WIN_POS_MOUSE);
+	gtk_window_set_position (GTK_WINDOW(find_dialog.window1),GTK_WIN_POS_CENTER);
 	gtk_window_set_transient_for(GTK_WINDOW(find_dialog.window1), GTK_WINDOW(main_window.window));
 	gtk_container_set_border_width (GTK_CONTAINER (find_dialog.window1), 6);
 	gtk_window_set_title (GTK_WINDOW (find_dialog.window1), _("Find"));
@@ -141,6 +140,21 @@ void find_create(void)
 	find_dialog.entry1 = gtk_entry_new ();
 	gtk_widget_show (find_dialog.entry1);
 	gtk_container_add (GTK_CONTAINER (find_dialog.alignment1), find_dialog.entry1);
+	/* Get selected text (Wendell) */
+	gint wordStart;
+	gint wordEnd;
+	gint length;
+	gchar *buffer;
+
+	if (main_window.current_editor->type != TAB_HELP) {
+		wordStart = gtk_scintilla_get_selection_start(GTK_SCINTILLA(main_window.current_editor->scintilla));
+		wordEnd = gtk_scintilla_get_selection_end(GTK_SCINTILLA(main_window.current_editor->scintilla));
+		if (wordStart != wordEnd) {
+			buffer = gtk_scintilla_get_text_range (GTK_SCINTILLA(main_window.current_editor->scintilla), wordStart, wordEnd, &length);
+			gtk_entry_set_text(GTK_ENTRY(find_dialog.entry1), buffer);
+		}
+	}
+	/* End get selected text */
 
 	find_dialog.label1 = gtk_label_new (_("RegExp/String to search"));
 	gtk_widget_show (find_dialog.label1);
@@ -364,7 +378,7 @@ void replace_clicked(GtkButton *button, gpointer data)
 
 	if (result == -1) {
 		// Show message saying could not be found.
-		gnome_dialog_run_and_close(GNOME_DIALOG(gnome_ok_dialog(_("Text not found."))));
+		gnome_dialog_run_and_close(GNOME_DIALOG(gnome_ok_dialog(g_strdup_printf(_("The text \"%s\" was not found."), text))));
 	}
 	else {
 		if (start_found == last_found) {
@@ -493,6 +507,7 @@ void replace_create(void)
 	replace_dialog.radiobutton22_group = NULL;
 
 	replace_dialog.window2 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_position (GTK_WINDOW(replace_dialog.window2),GTK_WIN_POS_CENTER);
 	gtk_container_set_border_width (GTK_CONTAINER (replace_dialog.window2), 6);
 	gtk_window_set_title (GTK_WINDOW (replace_dialog.window2), _("Find and Replace"));
 
@@ -512,6 +527,21 @@ void replace_create(void)
 	replace_dialog.entry1 = gtk_entry_new ();
 	gtk_widget_show (replace_dialog.entry1);
 	gtk_container_add (GTK_CONTAINER (replace_dialog.alignment1), replace_dialog.entry1);
+	/* Get selected text (Wendell) */
+	gint wordStart;
+	gint wordEnd;
+	gint length;
+	gchar *buffer;
+
+	if (main_window.current_editor->type != TAB_HELP) {
+		wordStart = gtk_scintilla_get_selection_start(GTK_SCINTILLA(main_window.current_editor->scintilla));
+		wordEnd = gtk_scintilla_get_selection_end(GTK_SCINTILLA(main_window.current_editor->scintilla));
+		if (wordStart != wordEnd) {
+			buffer = gtk_scintilla_get_text_range (GTK_SCINTILLA(main_window.current_editor->scintilla), wordStart, wordEnd, &length);
+			gtk_entry_set_text(GTK_ENTRY(replace_dialog.entry1), buffer);
+		}
+	}
+	/* End get selected text */
 	
 	replace_dialog.label10 = gtk_label_new (_("RegExp/String to search"));
 	gtk_widget_show (replace_dialog.label10);
