@@ -636,6 +636,18 @@ void gtk_scintilla_marker_define_pixmap(GtkScintilla *sci, int marker_number, co
         2049, (gulong) marker_number, (gulong) pixmap);
 }
 
+void gtk_scintilla_marker_add_set(GtkScintilla *sci, int line, int set)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2466, (gulong) line, (gulong) set);
+}
+
+void gtk_scintilla_marker_set_alpha(GtkScintilla *sci, int marker_number, int alpha)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2476, (gulong) marker_number, (gulong) alpha);
+}
+
 void gtk_scintilla_set_margin_type_n(GtkScintilla *sci, int margin, int margin_type)
 {
     scintilla_send_message(SCINTILLA(sci->scintilla),
@@ -774,6 +786,18 @@ void gtk_scintilla_set_sel_back(GtkScintilla *sci, gint use_setting, glong back)
         2068, (gulong) use_setting, (gulong) back);
 }
 
+int gtk_scintilla_get_sel_alpha(GtkScintilla *sci)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        2477, 0, 0);
+}
+
+void gtk_scintilla_set_sel_alpha(GtkScintilla *sci, int alpha)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2478, (gulong) alpha, 0);
+}
+
 void gtk_scintilla_set_caret_fore(GtkScintilla *sci, glong fore)
 {
     scintilla_send_message(SCINTILLA(sci->scintilla),
@@ -1074,6 +1098,30 @@ void gtk_scintilla_autoc_set_type_separator(GtkScintilla *sci, int separator_cha
         2286, (gulong) separator_character, 0);
 }
 
+void gtk_scintilla_autoc_set_max_width(GtkScintilla *sci, int character_count)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2208, (gulong) character_count, 0);
+}
+
+int gtk_scintilla_autoc_get_max_width(GtkScintilla *sci)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        2209, 0, 0);
+}
+
+void gtk_scintilla_autoc_set_max_height(GtkScintilla *sci, int row_count)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2210, (gulong) row_count, 0);
+}
+
+int gtk_scintilla_autoc_get_max_height(GtkScintilla *sci)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        2211, 0, 0);
+}
+
 void gtk_scintilla_set_indent(GtkScintilla *sci, int indent_size)
 {
     scintilla_send_message(SCINTILLA(sci->scintilla),
@@ -1566,6 +1614,12 @@ void gtk_scintilla_call_tip_set_fore_hlt(GtkScintilla *sci, glong fore)
         2207, (gulong) fore, 0);
 }
 
+void gtk_scintilla_call_tip_use_style(GtkScintilla *sci, int tab_size)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2212, (gulong) tab_size, 0);
+}
+
 int gtk_scintilla_visible_from_doc_line(GtkScintilla *sci, int line)
 {
     return scintilla_send_message(SCINTILLA(sci->scintilla),
@@ -1578,6 +1632,12 @@ int gtk_scintilla_doc_line_from_visible(GtkScintilla *sci, int line_display)
         2221, (gulong) line_display, 0);
 }
 
+int gtk_scintilla_wrap_count(GtkScintilla *sci, int line)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        2235, (gulong) line, 0);
+}
+
 void gtk_scintilla_set_fold_level(GtkScintilla *sci, int line, int level)
 {
     scintilla_send_message(SCINTILLA(sci->scintilla),
@@ -1716,6 +1776,42 @@ int gtk_scintilla_get_wrap_mode(GtkScintilla *sci)
         2269, 0, 0);
 }
 
+void gtk_scintilla_set_wrap_visual_flags(GtkScintilla *sci, int wrap_visual_flags)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2460, (gulong) wrap_visual_flags, 0);
+}
+
+int gtk_scintilla_get_wrap_visual_flags(GtkScintilla *sci)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        2461, 0, 0);
+}
+
+void gtk_scintilla_set_wrap_visual_flags_location(GtkScintilla *sci, int wrap_visual_flags_location)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2462, (gulong) wrap_visual_flags_location, 0);
+}
+
+int gtk_scintilla_get_wrap_visual_flags_location(GtkScintilla *sci)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        2463, 0, 0);
+}
+
+void gtk_scintilla_set_wrap_start_indent(GtkScintilla *sci, int indent)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2464, (gulong) indent, 0);
+}
+
+int gtk_scintilla_get_wrap_start_indent(GtkScintilla *sci)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        2465, 0, 0);
+}
+
 void gtk_scintilla_set_layout_cache(GtkScintilla *sci, int mode)
 {
     scintilla_send_message(SCINTILLA(sci->scintilla),
@@ -1752,7 +1848,7 @@ void gtk_scintilla_set_end_at_last_line(GtkScintilla *sci, gint end_at_last_line
         2277, (gulong) end_at_last_line, 0);
 }
 
-int gtk_scintilla_get_end_at_last_line(GtkScintilla *sci)
+gint gtk_scintilla_get_end_at_last_line(GtkScintilla *sci)
 {
     return scintilla_send_message(SCINTILLA(sci->scintilla),
         2278, 0, 0);
@@ -2700,6 +2796,84 @@ int gtk_scintilla_autoc_get_current(GtkScintilla *sci)
         2445, 0, 0);
 }
 
+void gtk_scintilla_allocate(GtkScintilla *sci, int bytes)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2446, (gulong) bytes, 0);
+}
+
+int gtk_scintilla_target_as_u_t_f8(GtkScintilla *sci, gchar * s)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        2447, 0, (gulong) s);
+}
+
+void gtk_scintilla_set_length_for_encode(GtkScintilla *sci, int bytes)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2448, (gulong) bytes, 0);
+}
+
+int gtk_scintilla_encoded_from_u_t_f8(GtkScintilla *sci, const gchar * utf8, gchar * encoded)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        2449, (gulong) utf8, (gulong) encoded);
+}
+
+int gtk_scintilla_find_column(GtkScintilla *sci, int line, int column)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        2456, (gulong) line, (gulong) column);
+}
+
+gint gtk_scintilla_get_caret_sticky(GtkScintilla *sci)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        2457, 0, 0);
+}
+
+void gtk_scintilla_set_caret_sticky(GtkScintilla *sci, gint use_caret_sticky_behaviour)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2458, (gulong) use_caret_sticky_behaviour, 0);
+}
+
+void gtk_scintilla_toggle_caret_sticky(GtkScintilla *sci)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2459, 0, 0);
+}
+
+void gtk_scintilla_set_paste_convert_endings(GtkScintilla *sci, gint convert)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2467, (gulong) convert, 0);
+}
+
+gint gtk_scintilla_get_paste_convert_endings(GtkScintilla *sci)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        2468, 0, 0);
+}
+
+void gtk_scintilla_selection_duplicate(GtkScintilla *sci)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2469, 0, 0);
+}
+
+void gtk_scintilla_set_caret_line_back_alpha(GtkScintilla *sci, int alpha)
+{
+    scintilla_send_message(SCINTILLA(sci->scintilla),
+        2470, (gulong) alpha, 0);
+}
+
+int gtk_scintilla_get_caret_line_back_alpha(GtkScintilla *sci)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        2471, 0, 0);
+}
+
 void gtk_scintilla_start_record(GtkScintilla *sci)
 {
     scintilla_send_message(SCINTILLA(sci->scintilla),
@@ -2754,6 +2928,30 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path)
         4007, 0, (gulong) path);
 }
 
+int gtk_scintilla_get_property(GtkScintilla *sci, const gchar * key, gchar * buf)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        4008, (gulong) key, (gulong) buf);
+}
+
+int gtk_scintilla_get_property_expanded(GtkScintilla *sci, const gchar * key, gchar * buf)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        4009, (gulong) key, (gulong) buf);
+}
+
+int gtk_scintilla_get_property_int(GtkScintilla *sci, const gchar * key)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        4010, (gulong) key, 0);
+}
+
+int gtk_scintilla_get_style_bits_needed(GtkScintilla *sci)
+{
+    return scintilla_send_message(SCINTILLA(sci->scintilla),
+        4011, 0, 0);
+}
+
 
 /* --- End of autogenerated code --- */
 
