@@ -162,6 +162,7 @@ void gtk_scintilla_set_use_palette(GtkScintilla *sci, gint use_palette);
 #define SC_MARK_DOTDOTDOT 23
 #define SC_MARK_ARROWS 24
 #define SC_MARK_PIXMAP 25
+#define SC_MARK_FULLRECT 26
 #define SC_MARK_CHARACTER 10000
 #define SC_MARKNUM_FOLDEREND 25
 #define SC_MARKNUM_FOLDEROPENMID 26
@@ -181,8 +182,12 @@ int gtk_scintilla_marker_get(GtkScintilla *sci, int line);
 int gtk_scintilla_marker_next(GtkScintilla *sci, int line_start, int marker_mask);
 int gtk_scintilla_marker_previous(GtkScintilla *sci, int line_start, int marker_mask);
 void gtk_scintilla_marker_define_pixmap(GtkScintilla *sci, int marker_number, const gchar * pixmap);
+void gtk_scintilla_marker_add_set(GtkScintilla *sci, int line, int set);
+void gtk_scintilla_marker_set_alpha(GtkScintilla *sci, int marker_number, int alpha);
 #define SC_MARGIN_SYMBOL 0
 #define SC_MARGIN_NUMBER 1
+#define SC_MARGIN_BACK 2
+#define SC_MARGIN_FORE 3
 void gtk_scintilla_set_margin_type_n(GtkScintilla *sci, int margin, int margin_type);
 int gtk_scintilla_get_margin_type_n(GtkScintilla *sci, int margin);
 void gtk_scintilla_set_margin_width_n(GtkScintilla *sci, int margin, int pixel_width);
@@ -197,6 +202,7 @@ gint gtk_scintilla_get_margin_sensitive_n(GtkScintilla *sci, int margin);
 #define STYLE_BRACEBAD 35
 #define STYLE_CONTROLCHAR 36
 #define STYLE_INDENTGUIDE 37
+#define STYLE_CALLTIP 38
 #define STYLE_LASTPREDEFINED 39
 #define STYLE_MAX 127
 #define SC_CHARSET_ANSI 0
@@ -210,6 +216,7 @@ gint gtk_scintilla_get_margin_sensitive_n(GtkScintilla *sci, int margin);
 #define SC_CHARSET_MAC 77
 #define SC_CHARSET_OEM 255
 #define SC_CHARSET_RUSSIAN 204
+#define SC_CHARSET_CYRILLIC 1251
 #define SC_CHARSET_SHIFTJIS 128
 #define SC_CHARSET_SYMBOL 2
 #define SC_CHARSET_TURKISH 162
@@ -218,6 +225,7 @@ gint gtk_scintilla_get_margin_sensitive_n(GtkScintilla *sci, int margin);
 #define SC_CHARSET_ARABIC 178
 #define SC_CHARSET_VIETNAMESE 163
 #define SC_CHARSET_THAI 222
+#define SC_CHARSET_8859_15 1000
 void gtk_scintilla_style_clear_all(GtkScintilla *sci);
 void gtk_scintilla_style_set_fore(GtkScintilla *sci, int style, glong fore);
 void gtk_scintilla_style_set_back(GtkScintilla *sci, int style, glong back);
@@ -236,6 +244,8 @@ void gtk_scintilla_style_set_character_set(GtkScintilla *sci, int style, int cha
 void gtk_scintilla_style_set_hot_spot(GtkScintilla *sci, int style, gint hotspot);
 void gtk_scintilla_set_sel_fore(GtkScintilla *sci, gint use_setting, glong fore);
 void gtk_scintilla_set_sel_back(GtkScintilla *sci, gint use_setting, glong back);
+int gtk_scintilla_get_sel_alpha(GtkScintilla *sci);
+void gtk_scintilla_set_sel_alpha(GtkScintilla *sci, int alpha);
 void gtk_scintilla_set_caret_fore(GtkScintilla *sci, glong fore);
 void gtk_scintilla_clear_all_cmd_keys(GtkScintilla *sci);
 void gtk_scintilla_set_styling_ex(GtkScintilla *sci, int length, const gchar * styles);
@@ -253,6 +263,7 @@ void gtk_scintilla_end_undo_action(GtkScintilla *sci);
 #define INDIC_STRIKE 4
 #define INDIC_HIDDEN 5
 #define INDIC_BOX 6
+#define INDIC_ROUNDBOX 7
 #define INDIC0_MASK 0x20
 #define INDIC1_MASK 0x40
 #define INDIC2_MASK 0x80
@@ -298,6 +309,10 @@ void gtk_scintilla_register_image(GtkScintilla *sci, int type, const gchar * xpm
 void gtk_scintilla_clear_registered_images(GtkScintilla *sci);
 int gtk_scintilla_autoc_get_type_separator(GtkScintilla *sci);
 void gtk_scintilla_autoc_set_type_separator(GtkScintilla *sci, int separator_character);
+void gtk_scintilla_autoc_set_max_width(GtkScintilla *sci, int character_count);
+int gtk_scintilla_autoc_get_max_width(GtkScintilla *sci);
+void gtk_scintilla_autoc_set_max_height(GtkScintilla *sci, int row_count);
+int gtk_scintilla_autoc_get_max_height(GtkScintilla *sci);
 void gtk_scintilla_set_indent(GtkScintilla *sci, int indent_size);
 int gtk_scintilla_get_indent(GtkScintilla *sci);
 void gtk_scintilla_set_use_tabs(GtkScintilla *sci, gint use_tabs);
@@ -390,8 +405,10 @@ void gtk_scintilla_call_tip_set_hlt(GtkScintilla *sci, int start, int end);
 void gtk_scintilla_call_tip_set_back(GtkScintilla *sci, glong back);
 void gtk_scintilla_call_tip_set_fore(GtkScintilla *sci, glong fore);
 void gtk_scintilla_call_tip_set_fore_hlt(GtkScintilla *sci, glong fore);
+void gtk_scintilla_call_tip_use_style(GtkScintilla *sci, int tab_size);
 int gtk_scintilla_visible_from_doc_line(GtkScintilla *sci, int line);
 int gtk_scintilla_doc_line_from_visible(GtkScintilla *sci, int line_display);
+int gtk_scintilla_wrap_count(GtkScintilla *sci, int line);
 #define SC_FOLDLEVELBASE 0x400
 #define SC_FOLDLEVELWHITEFLAG 0x1000
 #define SC_FOLDLEVELHEADERFLAG 0x2000
@@ -430,8 +447,21 @@ int gtk_scintilla_word_start_position(GtkScintilla *sci, glong pos, gint only_wo
 int gtk_scintilla_word_end_position(GtkScintilla *sci, glong pos, gint only_word_characters);
 #define SC_WRAP_NONE 0
 #define SC_WRAP_WORD 1
+#define SC_WRAP_CHAR 2
 void gtk_scintilla_set_wrap_mode(GtkScintilla *sci, int mode);
 int gtk_scintilla_get_wrap_mode(GtkScintilla *sci);
+#define SC_WRAPVISUALFLAG_NONE 0x0000
+#define SC_WRAPVISUALFLAG_END 0x0001
+#define SC_WRAPVISUALFLAG_START 0x0002
+void gtk_scintilla_set_wrap_visual_flags(GtkScintilla *sci, int wrap_visual_flags);
+int gtk_scintilla_get_wrap_visual_flags(GtkScintilla *sci);
+#define SC_WRAPVISUALFLAGLOC_DEFAULT 0x0000
+#define SC_WRAPVISUALFLAGLOC_END_BY_TEXT 0x0001
+#define SC_WRAPVISUALFLAGLOC_START_BY_TEXT 0x0002
+void gtk_scintilla_set_wrap_visual_flags_location(GtkScintilla *sci, int wrap_visual_flags_location);
+int gtk_scintilla_get_wrap_visual_flags_location(GtkScintilla *sci);
+void gtk_scintilla_set_wrap_start_indent(GtkScintilla *sci, int indent);
+int gtk_scintilla_get_wrap_start_indent(GtkScintilla *sci);
 #define SC_CACHE_NONE 0
 #define SC_CACHE_CARET 1
 #define SC_CACHE_PAGE 2
@@ -442,7 +472,7 @@ void gtk_scintilla_set_scroll_width(GtkScintilla *sci, int pixel_width);
 int gtk_scintilla_get_scroll_width(GtkScintilla *sci);
 int gtk_scintilla_text_width(GtkScintilla *sci, int style, const gchar * text);
 void gtk_scintilla_set_end_at_last_line(GtkScintilla *sci, gint end_at_last_line);
-int gtk_scintilla_get_end_at_last_line(GtkScintilla *sci);
+gint gtk_scintilla_get_end_at_last_line(GtkScintilla *sci);
 int gtk_scintilla_text_height(GtkScintilla *sci, int line);
 void gtk_scintilla_set_v_scroll_bar(GtkScintilla *sci, gint show);
 gint gtk_scintilla_get_v_scroll_bar(GtkScintilla *sci);
@@ -614,6 +644,22 @@ void gtk_scintilla_word_right_end_extend(GtkScintilla *sci);
 void gtk_scintilla_set_whitespace_chars(GtkScintilla *sci, const gchar * characters);
 void gtk_scintilla_set_chars_default(GtkScintilla *sci);
 int gtk_scintilla_autoc_get_current(GtkScintilla *sci);
+void gtk_scintilla_allocate(GtkScintilla *sci, int bytes);
+int gtk_scintilla_target_as_u_t_f8(GtkScintilla *sci, gchar * s);
+void gtk_scintilla_set_length_for_encode(GtkScintilla *sci, int bytes);
+int gtk_scintilla_encoded_from_u_t_f8(GtkScintilla *sci, const gchar * utf8, gchar * encoded);
+int gtk_scintilla_find_column(GtkScintilla *sci, int line, int column);
+gint gtk_scintilla_get_caret_sticky(GtkScintilla *sci);
+void gtk_scintilla_set_caret_sticky(GtkScintilla *sci, gint use_caret_sticky_behaviour);
+void gtk_scintilla_toggle_caret_sticky(GtkScintilla *sci);
+void gtk_scintilla_set_paste_convert_endings(GtkScintilla *sci, gint convert);
+gint gtk_scintilla_get_paste_convert_endings(GtkScintilla *sci);
+void gtk_scintilla_selection_duplicate(GtkScintilla *sci);
+#define SC_ALPHA_TRANSPARENT 0
+#define SC_ALPHA_OPAQUE 255
+#define SC_ALPHA_NOALPHA 256
+void gtk_scintilla_set_caret_line_back_alpha(GtkScintilla *sci, int alpha);
+int gtk_scintilla_get_caret_line_back_alpha(GtkScintilla *sci);
 void gtk_scintilla_start_record(GtkScintilla *sci);
 void gtk_scintilla_stop_record(GtkScintilla *sci);
 void gtk_scintilla_set_lexer(GtkScintilla *sci, int lexer);
@@ -624,6 +670,10 @@ void gtk_scintilla_set_property(GtkScintilla *sci, const gchar * key, const gcha
 void gtk_scintilla_set_keywords(GtkScintilla *sci, int keyword_set, const gchar * key_words);
 void gtk_scintilla_set_lexer_language(GtkScintilla *sci, const gchar * language);
 void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
+int gtk_scintilla_get_property(GtkScintilla *sci, const gchar * key, gchar * buf);
+int gtk_scintilla_get_property_expanded(GtkScintilla *sci, const gchar * key, gchar * buf);
+int gtk_scintilla_get_property_int(GtkScintilla *sci, const gchar * key);
+int gtk_scintilla_get_style_bits_needed(GtkScintilla *sci);
 #define SC_MOD_INSERTTEXT 0x1
 #define SC_MOD_DELETETEXT 0x2
 #define SC_MOD_CHANGESTYLE 0x4
@@ -631,11 +681,13 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SC_PERFORMED_USER 0x10
 #define SC_PERFORMED_UNDO 0x20
 #define SC_PERFORMED_REDO 0x40
+#define SC_MULTISTEPUNDOREDO 0x80
 #define SC_LASTSTEPINUNDOREDO 0x100
 #define SC_MOD_CHANGEMARKER 0x200
 #define SC_MOD_BEFOREINSERT 0x400
 #define SC_MOD_BEFOREDELETE 0x800
-#define SC_MODEVENTMASKALL 0xF77
+#define SC_MULTILINEUNDOREDO 0x1000
+#define SC_MODEVENTMASKALL 0x1FFF
 #define SCEN_CHANGE 768
 #define SCEN_SETFOCUS 512
 #define SCEN_KILLFOCUS 256
@@ -656,6 +708,7 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SCK_ADD 310
 #define SCK_SUBTRACT 311
 #define SCK_DIVIDE 312
+#define SCMOD_NORM 0
 #define SCMOD_SHIFT 1
 #define SCMOD_CTRL 2
 #define SCMOD_ALT 4
@@ -688,8 +741,6 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SCLEX_NNCRONTAB 26
 #define SCLEX_BULLANT 27
 #define SCLEX_VBSCRIPT 28
-#define SCLEX_ASP 29
-#define SCLEX_PHP 30
 #define SCLEX_BAAN 31
 #define SCLEX_MATLAB 32
 #define SCLEX_SCRIPTOL 33
@@ -714,6 +765,30 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SCLEX_FORTH 52
 #define SCLEX_ERLANG 53
 #define SCLEX_OCTAVE 54
+#define SCLEX_MSSQL 55
+#define SCLEX_VERILOG 56
+#define SCLEX_KIX 57
+#define SCLEX_GUI4CLI 58
+#define SCLEX_SPECMAN 59
+#define SCLEX_AU3 60
+#define SCLEX_APDL 61
+#define SCLEX_BASH 62
+#define SCLEX_ASN1 63
+#define SCLEX_VHDL 64
+#define SCLEX_CAML 65
+#define SCLEX_BLITZBASIC 66
+#define SCLEX_PUREBASIC 67
+#define SCLEX_HASKELL 68
+#define SCLEX_PHPSCRIPT 69
+#define SCLEX_TADS3 70
+#define SCLEX_REBOL 71
+#define SCLEX_SMALLTALK 72
+#define SCLEX_FLAGSHIP 73
+#define SCLEX_CSOUND 74
+#define SCLEX_FREEBASIC 75
+#define SCLEX_INNOSETUP 76
+#define SCLEX_OPAL 77
+#define SCLEX_SPICE 78
 #define SCLEX_AUTOMATIC 1000
 #define SCE_P_DEFAULT 0
 #define SCE_P_COMMENTLINE 1
@@ -729,6 +804,8 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SCE_P_IDENTIFIER 11
 #define SCE_P_COMMENTBLOCK 12
 #define SCE_P_STRINGEOL 13
+#define SCE_P_WORD2 14
+#define SCE_P_DECORATOR 15
 #define SCE_C_DEFAULT 0
 #define SCE_C_COMMENT 1
 #define SCE_C_COMMENTLINE 2
@@ -749,6 +826,28 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SCE_C_COMMENTDOCKEYWORD 17
 #define SCE_C_COMMENTDOCKEYWORDERROR 18
 #define SCE_C_GLOBALCLASS 19
+#define SCE_TCL_DEFAULT 0
+#define SCE_TCL_COMMENT 1
+#define SCE_TCL_COMMENTLINE 2
+#define SCE_TCL_NUMBER 3
+#define SCE_TCL_WORD_IN_QUOTE 4
+#define SCE_TCL_IN_QUOTE 5
+#define SCE_TCL_OPERATOR 6
+#define SCE_TCL_IDENTIFIER 7
+#define SCE_TCL_SUBSTITUTION 8
+#define SCE_TCL_SUB_BRACE 9
+#define SCE_TCL_MODIFIER 10
+#define SCE_TCL_EXPAND 11
+#define SCE_TCL_WORD 12
+#define SCE_TCL_WORD2 13
+#define SCE_TCL_WORD3 14
+#define SCE_TCL_WORD4 15
+#define SCE_TCL_WORD5 16
+#define SCE_TCL_WORD6 17
+#define SCE_TCL_WORD7 18
+#define SCE_TCL_WORD8 19
+#define SCE_TCL_COMMENT_BOX 20
+#define SCE_TCL_BLOCK_COMMENT 21
 #define SCE_H_DEFAULT 0
 #define SCE_H_TAG 1
 #define SCE_H_TAGUNKNOWN 2
@@ -836,6 +935,7 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SCE_HP_DEFNAME 100
 #define SCE_HP_OPERATOR 101
 #define SCE_HP_IDENTIFIER 102
+#define SCE_HPHP_COMPLEX_VARIABLE 104
 #define SCE_HPA_START 105
 #define SCE_HPA_DEFAULT 106
 #define SCE_HPA_COMMENTLINE 107
@@ -875,6 +975,7 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SCE_PL_ARRAY 13
 #define SCE_PL_HASH 14
 #define SCE_PL_SYMBOLTABLE 15
+#define SCE_PL_VARIABLE_INDEXER 16
 #define SCE_PL_REGEX 17
 #define SCE_PL_REGSUBST 18
 #define SCE_PL_LONGQUOTE 19
@@ -889,6 +990,41 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SCE_PL_STRING_QX 28
 #define SCE_PL_STRING_QR 29
 #define SCE_PL_STRING_QW 30
+#define SCE_PL_POD_VERB 31
+#define SCE_RB_DEFAULT 0
+#define SCE_RB_ERROR 1
+#define SCE_RB_COMMENTLINE 2
+#define SCE_RB_POD 3
+#define SCE_RB_NUMBER 4
+#define SCE_RB_WORD 5
+#define SCE_RB_STRING 6
+#define SCE_RB_CHARACTER 7
+#define SCE_RB_CLASSNAME 8
+#define SCE_RB_DEFNAME 9
+#define SCE_RB_OPERATOR 10
+#define SCE_RB_IDENTIFIER 11
+#define SCE_RB_REGEX 12
+#define SCE_RB_GLOBAL 13
+#define SCE_RB_SYMBOL 14
+#define SCE_RB_MODULE_NAME 15
+#define SCE_RB_INSTANCE_VAR 16
+#define SCE_RB_CLASS_VAR 17
+#define SCE_RB_BACKTICKS 18
+#define SCE_RB_DATASECTION 19
+#define SCE_RB_HERE_DELIM 20
+#define SCE_RB_HERE_Q 21
+#define SCE_RB_HERE_QQ 22
+#define SCE_RB_HERE_QX 23
+#define SCE_RB_STRING_Q 24
+#define SCE_RB_STRING_QQ 25
+#define SCE_RB_STRING_QX 26
+#define SCE_RB_STRING_QR 27
+#define SCE_RB_STRING_QW 28
+#define SCE_RB_WORD_DEMOTED 29
+#define SCE_RB_STDIN 30
+#define SCE_RB_STDOUT 31
+#define SCE_RB_STDERR 40
+#define SCE_RB_UPPER_BOUND 41
 #define SCE_B_DEFAULT 0
 #define SCE_B_COMMENT 1
 #define SCE_B_NUMBER 2
@@ -902,11 +1038,18 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SCE_B_KEYWORD2 10
 #define SCE_B_KEYWORD3 11
 #define SCE_B_KEYWORD4 12
+#define SCE_B_CONSTANT 13
+#define SCE_B_ASM 14
+#define SCE_B_LABEL 15
+#define SCE_B_ERROR 16
+#define SCE_B_HEXNUMBER 17
+#define SCE_B_BINNUMBER 18
 #define SCE_PROPS_DEFAULT 0
 #define SCE_PROPS_COMMENT 1
 #define SCE_PROPS_SECTION 2
 #define SCE_PROPS_ASSIGNMENT 3
 #define SCE_PROPS_DEFVAL 4
+#define SCE_PROPS_KEY 5
 #define SCE_L_DEFAULT 0
 #define SCE_L_COMMAND 1
 #define SCE_L_TAG 2
@@ -951,6 +1094,8 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SCE_ERR_IFC 16
 #define SCE_ERR_IFORT 17
 #define SCE_ERR_ABSF 18
+#define SCE_ERR_TIDY 19
+#define SCE_ERR_JAVA_STACK 20
 #define SCE_BAT_DEFAULT 0
 #define SCE_BAT_COMMENT 1
 #define SCE_BAT_WORD 2
@@ -1025,10 +1170,14 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SCE_LISP_COMMENT 1
 #define SCE_LISP_NUMBER 2
 #define SCE_LISP_KEYWORD 3
+#define SCE_LISP_KEYWORD_KW 4
+#define SCE_LISP_SYMBOL 5
 #define SCE_LISP_STRING 6
 #define SCE_LISP_STRINGEOL 8
 #define SCE_LISP_IDENTIFIER 9
 #define SCE_LISP_OPERATOR 10
+#define SCE_LISP_SPECIAL 11
+#define SCE_LISP_MULTI_COMMENT 12
 #define SCE_EIFFEL_DEFAULT 0
 #define SCE_EIFFEL_COMMENTLINE 1
 #define SCE_EIFFEL_NUMBER 2
@@ -1131,6 +1280,8 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SCE_CSS_DIRECTIVE 12
 #define SCE_CSS_DOUBLESTRING 13
 #define SCE_CSS_SINGLESTRING 14
+#define SCE_CSS_IDENTIFIER2 15
+#define SCE_CSS_ATTRIBUTE 16
 #define SCE_POV_DEFAULT 0
 #define SCE_POV_COMMENT 1
 #define SCE_POV_COMMENTLINE 2
@@ -1201,6 +1352,11 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SCE_NSIS_IFDEFINEDEF 11
 #define SCE_NSIS_MACRODEF 12
 #define SCE_NSIS_STRINGVAR 13
+#define SCE_NSIS_NUMBER 14
+#define SCE_NSIS_SECTIONGROUP 15
+#define SCE_NSIS_PAGEEX 16
+#define SCE_NSIS_FUNCTIONDEF 17
+#define SCE_NSIS_COMMENTBOX 18
 #define SCE_MMIXAL_LEADWS 0
 #define SCE_MMIXAL_COMMENT 1
 #define SCE_MMIXAL_LABEL 2
@@ -1229,11 +1385,13 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SCE_CLW_PICTURE_STRING 7
 #define SCE_CLW_KEYWORD 8
 #define SCE_CLW_COMPILER_DIRECTIVE 9
-#define SCE_CLW_BUILTIN_PROCEDURES_FUNCTION 10
-#define SCE_CLW_STRUCTURE_DATA_TYPE 11
-#define SCE_CLW_ATTRIBUTE 12
-#define SCE_CLW_STANDARD_EQUATE 13
-#define SCE_CLW_ERROR 14
+#define SCE_CLW_RUNTIME_EXPRESSIONS 10
+#define SCE_CLW_BUILTIN_PROCEDURES_FUNCTION 11
+#define SCE_CLW_STRUCTURE_DATA_TYPE 12
+#define SCE_CLW_ATTRIBUTE 13
+#define SCE_CLW_STANDARD_EQUATE 14
+#define SCE_CLW_ERROR 15
+#define SCE_CLW_DEPRECATED 16
 #define SCE_LOT_DEFAULT 0
 #define SCE_LOT_HEADER 1
 #define SCE_LOT_BREAK 2
@@ -1278,6 +1436,335 @@ void gtk_scintilla_load_lexer_library(GtkScintilla *sci, const gchar * path);
 #define SCE_ERLANG_SEPARATOR 12
 #define SCE_ERLANG_NODE_NAME 13
 #define SCE_ERLANG_UNKNOWN 31
+#define SCE_MSSQL_DEFAULT 0
+#define SCE_MSSQL_COMMENT 1
+#define SCE_MSSQL_LINE_COMMENT 2
+#define SCE_MSSQL_NUMBER 3
+#define SCE_MSSQL_STRING 4
+#define SCE_MSSQL_OPERATOR 5
+#define SCE_MSSQL_IDENTIFIER 6
+#define SCE_MSSQL_VARIABLE 7
+#define SCE_MSSQL_COLUMN_NAME 8
+#define SCE_MSSQL_STATEMENT 9
+#define SCE_MSSQL_DATATYPE 10
+#define SCE_MSSQL_SYSTABLE 11
+#define SCE_MSSQL_GLOBAL_VARIABLE 12
+#define SCE_MSSQL_FUNCTION 13
+#define SCE_MSSQL_STORED_PROCEDURE 14
+#define SCE_MSSQL_DEFAULT_PREF_DATATYPE 15
+#define SCE_MSSQL_COLUMN_NAME_2 16
+#define SCE_V_DEFAULT 0
+#define SCE_V_COMMENT 1
+#define SCE_V_COMMENTLINE 2
+#define SCE_V_COMMENTLINEBANG 3
+#define SCE_V_NUMBER 4
+#define SCE_V_WORD 5
+#define SCE_V_STRING 6
+#define SCE_V_WORD2 7
+#define SCE_V_WORD3 8
+#define SCE_V_PREPROCESSOR 9
+#define SCE_V_OPERATOR 10
+#define SCE_V_IDENTIFIER 11
+#define SCE_V_STRINGEOL 12
+#define SCE_V_USER 19
+#define SCE_KIX_DEFAULT 0
+#define SCE_KIX_COMMENT 1
+#define SCE_KIX_STRING1 2
+#define SCE_KIX_STRING2 3
+#define SCE_KIX_NUMBER 4
+#define SCE_KIX_VAR 5
+#define SCE_KIX_MACRO 6
+#define SCE_KIX_KEYWORD 7
+#define SCE_KIX_FUNCTIONS 8
+#define SCE_KIX_OPERATOR 9
+#define SCE_KIX_IDENTIFIER 31
+#define SCE_GC_DEFAULT 0
+#define SCE_GC_COMMENTLINE 1
+#define SCE_GC_COMMENTBLOCK 2
+#define SCE_GC_GLOBAL 3
+#define SCE_GC_EVENT 4
+#define SCE_GC_ATTRIBUTE 5
+#define SCE_GC_CONTROL 6
+#define SCE_GC_COMMAND 7
+#define SCE_GC_STRING 8
+#define SCE_GC_OPERATOR 9
+#define SCE_SN_DEFAULT 0
+#define SCE_SN_CODE 1
+#define SCE_SN_COMMENTLINE 2
+#define SCE_SN_COMMENTLINEBANG 3
+#define SCE_SN_NUMBER 4
+#define SCE_SN_WORD 5
+#define SCE_SN_STRING 6
+#define SCE_SN_WORD2 7
+#define SCE_SN_WORD3 8
+#define SCE_SN_PREPROCESSOR 9
+#define SCE_SN_OPERATOR 10
+#define SCE_SN_IDENTIFIER 11
+#define SCE_SN_STRINGEOL 12
+#define SCE_SN_REGEXTAG 13
+#define SCE_SN_SIGNAL 14
+#define SCE_SN_USER 19
+#define SCE_AU3_DEFAULT 0
+#define SCE_AU3_COMMENT 1
+#define SCE_AU3_COMMENTBLOCK 2
+#define SCE_AU3_NUMBER 3
+#define SCE_AU3_FUNCTION 4
+#define SCE_AU3_KEYWORD 5
+#define SCE_AU3_MACRO 6
+#define SCE_AU3_STRING 7
+#define SCE_AU3_OPERATOR 8
+#define SCE_AU3_VARIABLE 9
+#define SCE_AU3_SENT 10
+#define SCE_AU3_PREPROCESSOR 11
+#define SCE_AU3_SPECIAL 12
+#define SCE_AU3_EXPAND 13
+#define SCE_AU3_COMOBJ 14
+#define SCE_AU3_UDF 15
+#define SCE_APDL_DEFAULT 0
+#define SCE_APDL_COMMENT 1
+#define SCE_APDL_COMMENTBLOCK 2
+#define SCE_APDL_NUMBER 3
+#define SCE_APDL_STRING 4
+#define SCE_APDL_OPERATOR 5
+#define SCE_APDL_WORD 6
+#define SCE_APDL_PROCESSOR 7
+#define SCE_APDL_COMMAND 8
+#define SCE_APDL_SLASHCOMMAND 9
+#define SCE_APDL_STARCOMMAND 10
+#define SCE_APDL_ARGUMENT 11
+#define SCE_APDL_FUNCTION 12
+#define SCE_SH_DEFAULT 0
+#define SCE_SH_ERROR 1
+#define SCE_SH_COMMENTLINE 2
+#define SCE_SH_NUMBER 3
+#define SCE_SH_WORD 4
+#define SCE_SH_STRING 5
+#define SCE_SH_CHARACTER 6
+#define SCE_SH_OPERATOR 7
+#define SCE_SH_IDENTIFIER 8
+#define SCE_SH_SCALAR 9
+#define SCE_SH_PARAM 10
+#define SCE_SH_BACKTICKS 11
+#define SCE_SH_HERE_DELIM 12
+#define SCE_SH_HERE_Q 13
+#define SCE_ASN1_DEFAULT 0
+#define SCE_ASN1_COMMENT 1
+#define SCE_ASN1_IDENTIFIER 2
+#define SCE_ASN1_STRING 3
+#define SCE_ASN1_OID 4
+#define SCE_ASN1_SCALAR 5
+#define SCE_ASN1_KEYWORD 6
+#define SCE_ASN1_ATTRIBUTE 7
+#define SCE_ASN1_DESCRIPTOR 8
+#define SCE_ASN1_TYPE 9
+#define SCE_ASN1_OPERATOR 10
+#define SCE_VHDL_DEFAULT 0
+#define SCE_VHDL_COMMENT 1
+#define SCE_VHDL_COMMENTLINEBANG 2
+#define SCE_VHDL_NUMBER 3
+#define SCE_VHDL_STRING 4
+#define SCE_VHDL_OPERATOR 5
+#define SCE_VHDL_IDENTIFIER 6
+#define SCE_VHDL_STRINGEOL 7
+#define SCE_VHDL_KEYWORD 8
+#define SCE_VHDL_STDOPERATOR 9
+#define SCE_VHDL_ATTRIBUTE 10
+#define SCE_VHDL_STDFUNCTION 11
+#define SCE_VHDL_STDPACKAGE 12
+#define SCE_VHDL_STDTYPE 13
+#define SCE_VHDL_USERWORD 14
+#define SCE_CAML_DEFAULT 0
+#define SCE_CAML_IDENTIFIER 1
+#define SCE_CAML_TAGNAME 2
+#define SCE_CAML_KEYWORD 3
+#define SCE_CAML_KEYWORD2 4
+#define SCE_CAML_KEYWORD3 5
+#define SCE_CAML_LINENUM 6
+#define SCE_CAML_OPERATOR 7
+#define SCE_CAML_NUMBER 8
+#define SCE_CAML_CHAR 9
+#define SCE_CAML_STRING 11
+#define SCE_CAML_COMMENT 12
+#define SCE_CAML_COMMENT1 13
+#define SCE_CAML_COMMENT2 14
+#define SCE_CAML_COMMENT3 15
+#define SCE_HA_DEFAULT 0
+#define SCE_HA_IDENTIFIER 1
+#define SCE_HA_KEYWORD 2
+#define SCE_HA_NUMBER 3
+#define SCE_HA_STRING 4
+#define SCE_HA_CHARACTER 5
+#define SCE_HA_CLASS 6
+#define SCE_HA_MODULE 7
+#define SCE_HA_CAPITAL 8
+#define SCE_HA_DATA 9
+#define SCE_HA_IMPORT 10
+#define SCE_HA_OPERATOR 11
+#define SCE_HA_INSTANCE 12
+#define SCE_HA_COMMENTLINE 13
+#define SCE_HA_COMMENTBLOCK 14
+#define SCE_HA_COMMENTBLOCK2 15
+#define SCE_HA_COMMENTBLOCK3 16
+#define SCE_T3_DEFAULT 0
+#define SCE_T3_X_DEFAULT 1
+#define SCE_T3_PREPROCESSOR 2
+#define SCE_T3_BLOCK_COMMENT 3
+#define SCE_T3_LINE_COMMENT 4
+#define SCE_T3_OPERATOR 5
+#define SCE_T3_KEYWORD 6
+#define SCE_T3_NUMBER 7
+#define SCE_T3_IDENTIFIER 8
+#define SCE_T3_S_STRING 9
+#define SCE_T3_D_STRING 10
+#define SCE_T3_X_STRING 11
+#define SCE_T3_LIB_DIRECTIVE 12
+#define SCE_T3_MSG_PARAM 13
+#define SCE_T3_HTML_TAG 14
+#define SCE_T3_HTML_DEFAULT 15
+#define SCE_T3_HTML_STRING 16
+#define SCE_T3_USER1 17
+#define SCE_T3_USER2 18
+#define SCE_T3_USER3 19
+#define SCE_REBOL_DEFAULT 0
+#define SCE_REBOL_COMMENTLINE 1
+#define SCE_REBOL_COMMENTBLOCK 2
+#define SCE_REBOL_PREFACE 3
+#define SCE_REBOL_OPERATOR 4
+#define SCE_REBOL_CHARACTER 5
+#define SCE_REBOL_QUOTEDSTRING 6
+#define SCE_REBOL_BRACEDSTRING 7
+#define SCE_REBOL_NUMBER 8
+#define SCE_REBOL_PAIR 9
+#define SCE_REBOL_TUPLE 10
+#define SCE_REBOL_BINARY 11
+#define SCE_REBOL_MONEY 12
+#define SCE_REBOL_ISSUE 13
+#define SCE_REBOL_TAG 14
+#define SCE_REBOL_FILE 15
+#define SCE_REBOL_EMAIL 16
+#define SCE_REBOL_URL 17
+#define SCE_REBOL_DATE 18
+#define SCE_REBOL_TIME 19
+#define SCE_REBOL_IDENTIFIER 20
+#define SCE_REBOL_WORD 21
+#define SCE_REBOL_WORD2 22
+#define SCE_REBOL_WORD3 23
+#define SCE_REBOL_WORD4 24
+#define SCE_REBOL_WORD5 25
+#define SCE_REBOL_WORD6 26
+#define SCE_REBOL_WORD7 27
+#define SCE_REBOL_WORD8 28
+#define SCE_SQL_DEFAULT 0
+#define SCE_SQL_COMMENT 1
+#define SCE_SQL_COMMENTLINE 2
+#define SCE_SQL_COMMENTDOC 3
+#define SCE_SQL_NUMBER 4
+#define SCE_SQL_WORD 5
+#define SCE_SQL_STRING 6
+#define SCE_SQL_CHARACTER 7
+#define SCE_SQL_SQLPLUS 8
+#define SCE_SQL_SQLPLUS_PROMPT 9
+#define SCE_SQL_OPERATOR 10
+#define SCE_SQL_IDENTIFIER 11
+#define SCE_SQL_SQLPLUS_COMMENT 13
+#define SCE_SQL_COMMENTLINEDOC 15
+#define SCE_SQL_WORD2 16
+#define SCE_SQL_COMMENTDOCKEYWORD 17
+#define SCE_SQL_COMMENTDOCKEYWORDERROR 18
+#define SCE_SQL_USER1 19
+#define SCE_SQL_USER2 20
+#define SCE_SQL_USER3 21
+#define SCE_SQL_USER4 22
+#define SCE_SQL_QUOTEDIDENTIFIER 23
+#define SCE_ST_DEFAULT 0
+#define SCE_ST_STRING 1
+#define SCE_ST_NUMBER 2
+#define SCE_ST_COMMENT 3
+#define SCE_ST_SYMBOL 4
+#define SCE_ST_BINARY 5
+#define SCE_ST_BOOL 6
+#define SCE_ST_SELF 7
+#define SCE_ST_SUPER 8
+#define SCE_ST_NIL 9
+#define SCE_ST_GLOBAL 10
+#define SCE_ST_RETURN 11
+#define SCE_ST_SPECIAL 12
+#define SCE_ST_KWSEND 13
+#define SCE_ST_ASSIGN 14
+#define SCE_ST_CHARACTER 15
+#define SCE_ST_SPEC_SEL 16
+#define SCE_FS_DEFAULT 0
+#define SCE_FS_COMMENT 1
+#define SCE_FS_COMMENTLINE 2
+#define SCE_FS_COMMENTDOC 3
+#define SCE_FS_COMMENTLINEDOC 4
+#define SCE_FS_COMMENTDOCKEYWORD 5
+#define SCE_FS_COMMENTDOCKEYWORDERROR 6
+#define SCE_FS_KEYWORD 7
+#define SCE_FS_KEYWORD2 8
+#define SCE_FS_KEYWORD3 9
+#define SCE_FS_KEYWORD4 10
+#define SCE_FS_NUMBER 11
+#define SCE_FS_STRING 12
+#define SCE_FS_PREPROCESSOR 13
+#define SCE_FS_OPERATOR 14
+#define SCE_FS_IDENTIFIER 15
+#define SCE_FS_DATE 16
+#define SCE_FS_STRINGEOL 17
+#define SCE_FS_CONSTANT 18
+#define SCE_FS_ASM 19
+#define SCE_FS_LABEL 20
+#define SCE_FS_ERROR 21
+#define SCE_FS_HEXNUMBER 22
+#define SCE_FS_BINNUMBER 23
+#define SCE_CSOUND_DEFAULT 0
+#define SCE_CSOUND_COMMENT 1
+#define SCE_CSOUND_NUMBER 2
+#define SCE_CSOUND_OPERATOR 3
+#define SCE_CSOUND_INSTR 4
+#define SCE_CSOUND_IDENTIFIER 5
+#define SCE_CSOUND_OPCODE 6
+#define SCE_CSOUND_HEADERSTMT 7
+#define SCE_CSOUND_USERKEYWORD 8
+#define SCE_CSOUND_COMMENTBLOCK 9
+#define SCE_CSOUND_PARAM 10
+#define SCE_CSOUND_ARATE_VAR 11
+#define SCE_CSOUND_KRATE_VAR 12
+#define SCE_CSOUND_IRATE_VAR 13
+#define SCE_CSOUND_GLOBAL_VAR 14
+#define SCE_CSOUND_STRINGEOL 15
+#define SCE_INNO_DEFAULT 0
+#define SCE_INNO_COMMENT 1
+#define SCE_INNO_KEYWORD 2
+#define SCE_INNO_PARAMETER 3
+#define SCE_INNO_SECTION 4
+#define SCE_INNO_PREPROC 5
+#define SCE_INNO_PREPROC_INLINE 6
+#define SCE_INNO_COMMENT_PASCAL 7
+#define SCE_INNO_KEYWORD_PASCAL 8
+#define SCE_INNO_KEYWORD_USER 9
+#define SCE_INNO_STRING_DOUBLE 10
+#define SCE_INNO_STRING_SINGLE 11
+#define SCE_INNO_IDENTIFIER 12
+#define SCE_OPAL_SPACE 0
+#define SCE_OPAL_COMMENT_BLOCK 1
+#define SCE_OPAL_COMMENT_LINE 2
+#define SCE_OPAL_INTEGER 3
+#define SCE_OPAL_KEYWORD 4
+#define SCE_OPAL_SORT 5
+#define SCE_OPAL_STRING 6
+#define SCE_OPAL_PAR 7
+#define SCE_OPAL_BOOL_CONST 8
+#define SCE_OPAL_DEFAULT 32
+#define SCE_SPICE_DEFAULT 0
+#define SCE_SPICE_IDENTIFIER 1
+#define SCE_SPICE_KEYWORD 2
+#define SCE_SPICE_KEYWORD2 3
+#define SCE_SPICE_KEYWORD3 4
+#define SCE_SPICE_NUMBER 5
+#define SCE_SPICE_DELIMITER 6
+#define SCE_SPICE_VALUE 7
+#define SCE_SPICE_COMMENTLINE 8
 
 /* --- End of autogenerated code --- */
 
