@@ -30,6 +30,9 @@
 #include <libgnomevfs/gnome-vfs.h>
 #include "main.h"
 #include "main_window.h"
+#include "main_window_callbacks.h"
+#include "gphpedit_ipc.h"
+#include "templates.h"
 
 
 GnomeProgram* gphpedit_program;
@@ -40,6 +43,10 @@ int main (int argc, char **argv)
 	//GError *error;
 	gboolean vfs_inited;
 
+	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+
 	gphpedit_program = gnome_program_init ("gPHPEdit", VERSION, LIBGNOMEUI_MODULE,
 	                                       argc, argv, NULL);
 
