@@ -30,9 +30,8 @@
 #include <gnome.h>
 #include <glib.h>
 #include <gtkscintilla.h>
+#include <libgnome/gnome-i18n.h>
 
-
-#define PACKAGE_PIXMAPS_DIR "/usr/local/share/pixmaps"
 #define GPHPEDIT_PIXMAP_ICON "gphpedit.png"
 
 extern GnomeProgram* gphpedit_program;
