@@ -140,7 +140,7 @@ void force_config_folder(void)
 	ret = mkdir(dir, (S_IRUSR|S_IWUSR|S_IXUSR));
 	g_free(dir);
 	if (ret && errno != EEXIST) {
-		g_print("Unable to create ~/.gphpedit/ (%d)", errno);
+		g_print(_("Unable to create ~/.gphpedit/ (%d)"), errno);
 		exit(-1);
 	}
 
@@ -148,7 +148,7 @@ void force_config_folder(void)
 	ret = mkdir(dir, (S_IRUSR|S_IWUSR|S_IXUSR));
 	g_free(dir);
 	if (ret && errno != EEXIST) {
-		g_print("Unable to create ~/.gphpedit/plugins/ (%d)", errno);
+		g_print(_("Unable to create ~/.gphpedit/plugins/ (%d)"), errno);
 		exit(-1);
 	}
 }
@@ -261,9 +261,8 @@ static void main_window_create_panes(void)
 
 	gtk_signal_connect (GTK_OBJECT (main_window.window), "size_allocate", GTK_SIGNAL_FUNC (classbrowser_accept_size), NULL);
 	move_classbrowser_position();
-	if (gnome_config_get_int ("gPHPEdit/main_window/classbrowser_hidden=0") == 1) {
-		classbrowser_hide(NULL);
-	}
+	if (gnome_config_get_int ("gPHPEdit/main_window/classbrowser_hidden=0") == 1)
+		classbrowser_hide();
 }
 
 
@@ -476,20 +475,20 @@ void update_app_title(void)
 					g_string_append(title, _(" - gPHPEdit"));
 				}
 				else {
-					g_string_append(title, _(" (amended) - gPHPEdit"));
+					g_string_append(title, _(" (modified) - gPHPEdit"));
 				}
 			}
 			else {
-				title = g_string_new(_("gPHPEdit"));
+				title = g_string_new("gPHPEdit");
 			}
 			gtk_window_set_title(GTK_WINDOW(main_window.window), title->str);
 		}
 		else {
-			gtk_window_set_title(GTK_WINDOW(main_window.window), _("gPHPEdit"));
+			gtk_window_set_title(GTK_WINDOW(main_window.window), "gPHPEdit");
 		}
 	}
 	else {
-		gtk_window_set_title(GTK_WINDOW(main_window.window), _("gPHPEdit"));
+		gtk_window_set_title(GTK_WINDOW(main_window.window), "gPHPEdit");
 	}
 }
 
@@ -683,7 +682,7 @@ void plugin_exec(gint plugin_num)
 	
 	plugin = (Plugin *)g_list_nth_data(Plugins, plugin_num);
 	if (!plugin) {
-		g_print("Plugin is null!\n");
+		g_print(_("Plugin is null!\n"));
 	}
 	//g_print("Plugin No: %d:%d (%s):%s\n", plugin_num, plugin->type, plugin->name, plugin->filename->str);
 	command_line = g_string_new(plugin->filename->str);
@@ -737,7 +736,7 @@ void plugin_exec(gint plugin_num)
 
 	}
 	else {
-		g_print("Spawning %s gave error %s\n", plugin->filename->str, error->message);
+		g_print(_("Spawning %s gave error %s\n"), plugin->filename->str, error->message);
 	}
 }
 
@@ -833,9 +832,9 @@ void main_window_add_to_reopen_menu(gchar *full_filename)
 
 void main_window_create(void)
 {
-	gnome_window_icon_set_default_from_file(PACKAGE_PIXMAPS_DIR "/" GPHPEDIT_PIXMAP_ICON);
+	gnome_window_icon_set_default_from_file(PIXMAP_DIR "/" GPHPEDIT_PIXMAP_ICON);
 
-	main_window.window = gnome_app_new (_("gPHPEdit"), _("gPHPEdit"));
+	main_window.window = gnome_app_new ("gPHPEdit", "gPHPEdit");
 	preferences_apply();
 	
 	gnome_app_create_menus (GNOME_APP (main_window.window), menubar1_uiinfo);
@@ -856,6 +855,7 @@ void main_window_create(void)
 	gtk_signal_connect (GTK_OBJECT (main_window.window), "destroy", GTK_SIGNAL_FUNC (main_window_destroy_event), NULL);
 	gtk_signal_connect (GTK_OBJECT (main_window.window), "key_press_event", GTK_SIGNAL_FUNC (main_window_key_press_event), NULL);
 	gtk_signal_connect (GTK_OBJECT (main_window.window), "size_allocate", GTK_SIGNAL_FUNC (main_window_resize), NULL);
+	gtk_signal_connect (GTK_OBJECT (main_window.window), "window-state-event", GTK_SIGNAL_FUNC (main_window_state_changed), NULL);
 
 	main_window.clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
 
