@@ -60,7 +60,7 @@ void session_save(void)
 	
 		fp = fopen(session_file->str, "w");
   		if (!fp) {	
-			g_print("ERROR: cannot save session to %s\n", session_file->str);
+			g_print(_("ERROR: cannot save session to %s\n"), session_file->str);
 			return;
 		}
 
@@ -105,7 +105,7 @@ void session_reopen(void)
 	if (g_file_exists(session_file->str)) {
 		fp = fopen(session_file->str, "r");
   		if (!fp) {	
-			g_print("ERROR: cannot open session file (%s)\n", session_file->str);
+			g_print(_("ERROR: cannot open session file (%s)\n"), session_file->str);
 			return;
 		}
 
@@ -243,7 +243,15 @@ gboolean main_window_delete_event(GtkWidget *widget,
 
 void main_window_resize(GtkWidget *widget, GtkAllocation *allocation, gpointer user_data)
 {
-	main_window_size_save_details(allocation->x, allocation->y, allocation->width, allocation->height);
+	//main_window_size_save_details(allocation->x, allocation->y, allocation->width, allocation->height);
+	main_window_size_save_details();
+}
+
+void main_window_state_changed(GtkWidget *widget, GdkEventWindowState *event, gpointer user_data)
+{
+	gboolean maximized = GDK_WINDOW_STATE_MAXIMIZED && event->new_window_state;
+	gnome_config_set_bool("gPHPEdit/main_window/maximized", maximized);
+	gnome_config_sync();
 }
 
 gboolean classbrowser_accept_size(GtkPaned *paned, gpointer user_data)
@@ -257,21 +265,31 @@ gint main_window_key_press_event(GtkWidget   *widget,
 {
 	guint current_pos;
 	guint current_line;
-	guint search_length;
+	gint search_length;
 	gchar *search_buffer;
 	gchar *member_function_buffer;
-	guint member_function_length;
-	guint wordStart;
-	guint wordEnd;
+	gint member_function_length;
+	gint wordStart;
+	gint wordEnd;
 	
 	if (main_window.notebook_editor != NULL) {
 		if (((event->state & (GDK_CONTROL_MASK | GDK_SHIFT_MASK))==(GDK_CONTROL_MASK | GDK_SHIFT_MASK)) && (event->keyval == GDK_ISO_Left_Tab)) {
 			// Hack, for some reason when shift is held down keyval comes through as GDK_ISO_Left_Tab not GDK_Tab
-			gtk_notebook_prev_page(GTK_NOTEBOOK(main_window.notebook_editor));
+			if (gtk_notebook_get_current_page(GTK_NOTEBOOK(main_window.notebook_editor)) == 0) {
+				gtk_notebook_set_current_page(GTK_NOTEBOOK(main_window.notebook_editor),gtk_notebook_get_n_pages(GTK_NOTEBOOK(main_window.notebook_editor))-1);
+			}
+			else {
+				gtk_notebook_prev_page(GTK_NOTEBOOK(main_window.notebook_editor));
+			}
 			return TRUE;
 		}
 		else if ((event->state & GDK_CONTROL_MASK)==GDK_CONTROL_MASK && (event->keyval == GDK_Tab)) {
-			gtk_notebook_next_page(GTK_NOTEBOOK(main_window.notebook_editor));
+			if (gtk_notebook_get_current_page(GTK_NOTEBOOK(main_window.notebook_editor)) == gtk_notebook_get_n_pages(GTK_NOTEBOOK(main_window.notebook_editor))-1) {
+				gtk_notebook_set_current_page(GTK_NOTEBOOK(main_window.notebook_editor),0);
+			}
+			else {
+				gtk_notebook_next_page(GTK_NOTEBOOK(main_window.notebook_editor));
+			}
 			return TRUE;
 		}
 		else if ((event->state & GDK_CONTROL_MASK)==GDK_CONTROL_MASK && ((event->keyval == GDK_i) || (event->keyval == GDK_I))) {
@@ -359,7 +377,7 @@ void reopen_recent(GtkWidget *widget, gpointer data)
 	GString *key;
 	
 	key = g_string_new("gPHPEdit/recent/");
-	g_string_append_printf(key, "%d=NOTFOUND", (gulong)data); // Was (gint)
+	g_string_append_printf(key, "%d=NOTFOUND", (gint)data); // Back to being gint from gulong due to compiler warning
 	filename = gnome_config_get_string (key->str);
 	g_string_free(key, TRUE);
 
@@ -470,6 +488,7 @@ void on_open1_activate(GtkWidget *widget)
 		GTK_FILE_CHOOSER_ACTION_OPEN, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
 	
 	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER(file_selection_box), FALSE);
+	gtk_dialog_set_default_response (GTK_DIALOG(file_selection_box), GTK_RESPONSE_ACCEPT);	
 	
 	last_opened_folder = gnome_config_get_string("gPHPEdit/general/last_opened_folder=NOTFOUND");
 	if (DEBUG_MODE) { g_print("DEBUG: main_window_callbacks.c:on_open1_activate:last_opened_folder: %s\n", last_opened_folder); }
@@ -477,7 +496,7 @@ void on_open1_activate(GtkWidget *widget)
 	/* opening of multiple files at once */
 	gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(file_selection_box), TRUE);
 	
-	if (main_window.current_editor) {
+	if (main_window.current_editor && !main_window.current_editor->is_untitled) {
 		folder = get_folder(main_window.current_editor->filename);
 		if (DEBUG_MODE) { g_print("DEBUG: main_window_callbacks.c:on_open1_activate:folder: %s\n", folder->str); }
 		gtk_file_chooser_set_current_folder_uri(GTK_FILE_CHOOSER(file_selection_box),  folder->str);
@@ -532,7 +551,7 @@ void save_file_as_ok(GtkFileChooser *file_selection_box)
 	filename = g_string_new(gtk_file_chooser_get_uri(file_selection_box));
 
 	if (stat (filename->str, &st) == 0) {
-		file_exists_dialog = gnome_question_dialog_modal("This file already exists, are you sure you want to overwrite it?",
+		file_exists_dialog = gnome_question_dialog_modal(_("This file already exists, are you sure you want to overwrite it?"),
             save_file_as_confirm_overwrite,filename);
 		gnome_dialog_run_and_close(GNOME_DIALOG(file_exists_dialog));
 	}
@@ -592,18 +611,18 @@ void on_saveall1_activate(GtkWidget *widget)
 		editor = li->data;
 		if (editor) {
 			filename = editor->filename->str;
-			if (strcmp(filename, "Untitled")!=0) {
+			if (strcmp(filename, _("Untitled"))!=0) {
 				text_length = gtk_scintilla_get_length(GTK_SCINTILLA(editor->scintilla));
 	
 				write_buffer = g_malloc0(text_length+1); // Include terminating null
 	
 				if (write_buffer == NULL) {
-					g_warning ("%s", "Cannot allocate write buffer");
+					g_warning ("%s", _("Cannot allocate write buffer"));
 					return;
 				}
 	
 				if ((stream = fopen (filename, "w")) == NULL) {
-					g_message ("Cannot open '%s' for writing", editor->filename->str);
+					g_message (_("Cannot open '%s' for writing"), editor->filename->str);
 					return;
 				}
 	
@@ -636,6 +655,8 @@ void on_save_as1_activate(GtkWidget *widget)
 			GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT, NULL);
 
 		gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER(file_selection_box), FALSE);
+		gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER(file_selection_box), TRUE);
+		gtk_dialog_set_default_response (GTK_DIALOG(file_selection_box), GTK_RESPONSE_ACCEPT);
 	
 		last_opened_folder = gnome_config_get_string("gPHPEdit/general/last_opened_folder=NOTFOUND");
 		if (DEBUG_MODE) { g_print("DEBUG: main_window_callbacks.c:on_save_as1_activate:last_opened_folder: %s\n", last_opened_folder); }
@@ -828,7 +849,7 @@ gboolean try_save_page(Editor *editor, gboolean close_if_can)
 
 gboolean try_close_page(Editor *editor)
 {
-	if (!editor->saved && editor->type==TAB_FILE) {
+	if (!editor->saved && editor->type!=TAB_HELP) {
 		return try_save_page(editor, TRUE);
 	}
 	else {
@@ -868,9 +889,9 @@ void on_quit1_activate(GtkWidget *widget)
 
 void on_cut1_activate(GtkWidget *widget)
 {
-	guint wordStart;
-	guint wordEnd;
-	guint length;
+	gint wordStart;
+	gint wordEnd;
+	gint length;
 	gchar *buffer;
 	
 	if (main_window.current_editor == NULL || main_window.current_editor->type == TAB_HELP)
@@ -910,18 +931,19 @@ static gchar *gtkhtml2_selection_get_text (HtmlView *view)
 			g_assert_not_reached ();
 			break;
 		case HTML_BOX_TEXT_SELECTION_END:
-			g_string_append_len (str, text->canon_text, g_utf8_offset_to_pointer (text->canon_text, text->sel_end_index) - (gchar *)text->canon_text);
+			g_string_append_len (str, (gchar *)text->canon_text, g_utf8_offset_to_pointer ((gchar *)text->canon_text, (glong)text->sel_end_index) - (gchar *)text->canon_text);
 			break;
 		case HTML_BOX_TEXT_SELECTION_START:
-			g_string_append_len (str, g_utf8_offset_to_pointer (text->canon_text, text->sel_start_index),
-					 g_utf8_offset_to_pointer (text->canon_text, text->length) - g_utf8_offset_to_pointer (text->canon_text, text->sel_start_index));
+			g_string_append_len (str, g_utf8_offset_to_pointer ((gchar *)text->canon_text, (glong)text->sel_start_index),
+					 g_utf8_offset_to_pointer ((gchar *)text->canon_text, (glong)text->length) - g_utf8_offset_to_pointer ((gchar *)text->canon_text, (glong)text->sel_start_index));
 			break;
 		case HTML_BOX_TEXT_SELECTION_FULL:
-			g_string_append_len (str, text->canon_text, g_utf8_offset_to_pointer (text->canon_text, text->length) - (gchar *)text->canon_text);
+			g_string_append_len (str, (gchar *)text->canon_text, g_utf8_offset_to_pointer ((gchar *)text->canon_text, (glong)text->length) - (gchar *)text->canon_text);
 			break;
 		case HTML_BOX_TEXT_SELECTION_BOTH:
-			g_string_append_len (str, g_utf8_offset_to_pointer (text->canon_text, MIN (text->sel_start_index, text->sel_end_index)),
-					 g_utf8_offset_to_pointer (text->canon_text, MAX (text->sel_end_index, text->sel_start_index)) - g_utf8_offset_to_pointer (text->canon_text, MIN (text->sel_start_index, text->sel_end_index)));
+			g_string_append_len (str, g_utf8_offset_to_pointer ((gchar *)text->canon_text, (glong)MIN (text->sel_start_index, text->sel_end_index)),
+					g_utf8_offset_to_pointer ((gchar *)text->canon_text, (glong)MAX (text->sel_end_index, text->sel_start_index)) - 
+					g_utf8_offset_to_pointer ((gchar *)text->canon_text, (glong)MIN (text->sel_start_index, text->sel_end_index)));
 			break;
 		}
 	}
@@ -932,9 +954,9 @@ static gchar *gtkhtml2_selection_get_text (HtmlView *view)
 
 void on_copy1_activate(GtkWidget *widget)
 {
-	guint wordStart;
-	guint wordEnd;
-	guint length;
+	gint wordStart;
+	gint wordEnd;
+	gint length;
 	gchar *buffer;
 	
 	if (main_window.current_editor == NULL)
@@ -954,14 +976,20 @@ void on_copy1_activate(GtkWidget *widget)
 			gtk_clipboard_set_text(main_window.clipboard,buffer,length);
 		}
 	}
+	macro_record (main_window.current_editor->scintilla, 2178, 0, 0); // As copy doesn't change the buffer it doesn't get recorded, so do it manually
+	
 	//gtk_scintilla_copy(GTK_SCINTILLA(main_window.current_editor->scintilla));
 }
 
 
 void on_paste_got_from_cliboard(GtkClipboard *clipboard, const gchar *text, gpointer data)
 {
+	Editor *editor;
+	editor = editor_find_from_scintilla(data);
+	editor->is_pasting = editor->is_macro_recording;
 	gtk_scintilla_replace_sel(GTK_SCINTILLA(data), text);
-	
+	editor->is_pasting = FALSE;
+
 	// Possible fix for rendering issues after pasting
 	gtk_scintilla_colourise(GTK_SCINTILLA(main_window.current_editor->scintilla), 0, -1);
 }
@@ -1057,6 +1085,8 @@ void keyboard_macro_playback(GtkWidget *widget)
 		if (main_window.current_editor->keyboard_macro_list) {
 			for (current = main_window.current_editor->keyboard_macro_list; current; current = g_slist_next(current)) {
 				event = current->data;
+				if (DEBUG_MODE) { g_print("DEBUG: main_window_callbacks.c:keyboard_macro_playback:Message: %d (%s)\n", event->message, macro_message_to_string(event->message)); }
+
 				switch (event->message) {
 					case (2170) : gtk_scintilla_replace_sel(GTK_SCINTILLA(main_window.current_editor->scintilla), (gchar *)event->lparam); break;
 					case (2177) : gtk_scintilla_cut(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
@@ -1113,7 +1143,7 @@ void keyboard_macro_playback(GtkWidget *widget)
 					case (2347) : gtk_scintilla_line_end_display(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
 					case (2348) : gtk_scintilla_line_end_display_extend(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
 					default:
-						g_print("Unhandle keyboard macro function %d, please report to macro@gphpedit.org\n", event->message);
+						g_print(_("Unhandle keyboard macro function %d, please report to macro@gphpedit.org\n"), event->message);
 				}
 			}
 		}
@@ -1141,9 +1171,9 @@ void context_help(GtkWidget *widget)
 	gchar *buffer = NULL;
 	gint length;
 	GString *function;
-	guint wordStart;
-	guint wordEnd;
-
+	gint wordStart;
+	gint wordEnd;
+	
 	if (main_window.current_editor && main_window.current_editor->type != TAB_HELP) {
 		wordStart = gtk_scintilla_get_selection_start(GTK_SCINTILLA(main_window.current_editor->scintilla));
 		wordEnd = gtk_scintilla_get_selection_end(GTK_SCINTILLA(main_window.current_editor->scintilla));
@@ -1164,7 +1194,11 @@ void context_help(GtkWidget *widget)
 void on_about1_activate(GtkWidget *widget)
 {
 	const gchar *authors[] = {
-	                             "Andy Jeffries <andy@gphpedit.org>",
+	                             "Primary Developer/Team Lead:",
+								 "Andy Jeffries <andy@gphpedit.org>",
+								"",
+								"Assistance with Fixes/Enhancements:",
+				     "Jonh Wendell <wendell@bani.com.br>",
 				     "Tim Jackson <tim@timj.co.uk>",
 				     "Sven Herzberg <herzi@gnome-de.org>",
 	                             NULL
@@ -1172,21 +1206,24 @@ void on_about1_activate(GtkWidget *widget)
 	const gchar *documenters[] = {
 	                                 NULL
 	                             };
+	gchar *translator_credits = _("translator_credits");
 	GtkWidget *about;
 	GdkPixbuf *pixbuf = NULL;
 	GError *error = NULL;
 
-	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR "/" GPHPEDIT_PIXMAP_ICON, &error);
+	pixbuf = gdk_pixbuf_new_from_file (PIXMAP_DIR "/" GPHPEDIT_PIXMAP_ICON, &error);
 
 	if (error) {
 		g_warning (G_STRLOC ": cannot open icon: %s", error->message);
 		g_error_free (error);
 	}
 	about = gnome_about_new ("gPHPEdit", VERSION,
-	                         _("Copyright  2003 Andy Jeffries."),
+	                         _("Copyright  2003-2006 Andy Jeffries."),
                          	 _("gPHPEdit is a GNOME2 editor specialised for editing PHP "
 	                         "scripts and related files (HTML/CSS/JS)."),
-	                         (const gchar **) authors, (const gchar **) documenters, NULL,
+	                         (const gchar **) authors,
+	                         (const gchar **) documenters,
+	                         strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 	                         pixbuf);
 	gtk_widget_show(about);
 
@@ -1224,7 +1261,7 @@ void on_notebook_switch_page (GtkNotebook *notebook, GtkNotebookPage *page,
 			main_window.current_editor = data;
 		}
 		else {
-			g_print("Unable to get data for page %d\n", page_num);
+ 			g_print(_("Unable to get data for page %d\n"), page_num);
 		}
 	}
 	
@@ -1310,10 +1347,10 @@ void goto_line_int(gint line)
 {
 	gint current_pos;
 
+	gtk_scintilla_grab_focus(GTK_SCINTILLA(main_window.current_editor->scintilla));
 	gtk_scintilla_goto_line(GTK_SCINTILLA(main_window.current_editor->scintilla), line-1); // seems to be off by one...
 	current_pos = gtk_scintilla_get_current_pos(GTK_SCINTILLA(main_window.current_editor->scintilla));
 	gtk_scintilla_scroll_caret(GTK_SCINTILLA(main_window.current_editor->scintilla));
-	gtk_scintilla_grab_focus(GTK_SCINTILLA(main_window.current_editor->scintilla));
 }
 
 
@@ -1387,8 +1424,7 @@ void syntax_check_clear(GtkWidget *widget)
 	gtk_widget_hide(main_window.lint_view);
 }
 
-
-void classbrowser_show(GtkWidget *widget)
+void classbrowser_show(void)
 {
 	gtk_paned_set_position(GTK_PANED(main_window.main_horizontal_pane),classbrowser_hidden_position);
 	//g_print("Width of class browser is %d\n", classbrowser_hidden_position);
@@ -1398,7 +1434,7 @@ void classbrowser_show(GtkWidget *widget)
 }
 
 
-void classbrowser_hide(GtkWidget *widget)
+void classbrowser_hide(void)
 {
 	classbrowser_hidden_position = gnome_config_get_int ("gPHPEdit/main_window/classbrowser_size=100");
 	//g_print("Width of class browser is %d\n", classbrowser_hidden_position);
@@ -1407,6 +1443,16 @@ void classbrowser_hide(GtkWidget *widget)
 	gnome_config_sync();
 }
 
+void classbrowser_show_hide(GtkWidget *widget)
+{
+	gint hidden;
+	
+	hidden = gnome_config_get_int ("gPHPEdit/main_window/classbrowser_hidden=0");
+	if (hidden == 1)
+		classbrowser_show();
+	else
+		classbrowser_hide();
+}
 
 void lint_row_activated (GtkTreeSelection *selection, gpointer data)
 {
