@@ -101,15 +101,18 @@ void on_reload1_activate(GtkWidget *widget);
 gint treeview_double_click(GtkWidget *widget, GdkEventButton *event, gpointer func_data);
 gint treeview_click_release(GtkWidget *widget, GdkEventButton *event, gpointer func_data);
 void main_window_resize(GtkWidget *widget, GtkAllocation *allocation, gpointer user_data);
+void main_window_state_changed(GtkWidget *widget, GdkEventWindowState *event, gpointer user_data);
 gboolean classbrowser_accept_size(GtkPaned *paned, gpointer user_data);
 
 void keyboard_macro_startstop(GtkWidget *widget);
 void keyboard_macro_playback(GtkWidget *widget);
-void classbrowser_show(GtkWidget *widget);
-void classbrowser_hide(GtkWidget *widget);
+void classbrowser_show(void);
+void classbrowser_hide(void);
+void classbrowser_show_hide(GtkWidget *widget);
 void run_plugin(GtkWidget *widget, gpointer data);
 void close_all_tabs(void);
 void session_reopen(void);
+void session_save(void);
 
 
 #endif
