@@ -28,7 +28,7 @@
 #define MAIN_WINDOW_MENU_H
 
 #include "main_window_callbacks.h"
-
+#include <libgnome/gnome-i18n.h>
 
 
 static GnomeUIInfo recent_menu[] =
@@ -92,19 +92,19 @@ static GnomeUIInfo plugin_menu[] =
 		GNOMEUIINFO_END		
 	};	
 #define NUM_PLUGINS_MAX 30
-	
+
 static GnomeUIInfo file1_menu_uiinfo[] =
     {
-        GNOMEUIINFO_MENU_NEW_ITEM ("_New", NULL, on_new1_activate, NULL),
+        GNOMEUIINFO_MENU_NEW_ITEM (N_("_New"), NULL, on_new1_activate, NULL),
         GNOMEUIINFO_MENU_OPEN_ITEM (on_open1_activate, NULL),
-        { GNOME_APP_UI_ITEM, "Open selected file", "Open a file with the name currently selected in the editor", on_openselected1_activate, NULL,NULL, 0, 0, GDK_Return, GDK_CONTROL_MASK },
-		GNOMEUIINFO_SUBTREE("R_eopen recent", recent_menu),
-        { GNOME_APP_UI_ITEM, "Reload current file", "Reload the file currently selected in the editor", on_reload1_activate, NULL,NULL, 0, 0, 'o', GDK_SHIFT_MASK | GDK_CONTROL_MASK },
+        { GNOME_APP_UI_ITEM, N_("Open selected file"), N_("Open a file with the name currently selected in the editor"), on_openselected1_activate, NULL,NULL, 0, 0, GDK_Return, GDK_CONTROL_MASK },
+		GNOMEUIINFO_SUBTREE(N_("R_eopen recent"), recent_menu),
+        { GNOME_APP_UI_ITEM, N_("Reload current file"), N_("Reload the file currently selected in the editor"), on_reload1_activate, NULL,NULL, 0, 0, 'o', GDK_SHIFT_MASK | GDK_CONTROL_MASK },
         GNOMEUIINFO_SEPARATOR,
-        GNOMEUIINFO_MENU_SAVE_ITEM (on_save1_activate, NULL),
+		GNOMEUIINFO_MENU_SAVE_ITEM (on_save1_activate, NULL),
         GNOMEUIINFO_MENU_SAVE_AS_ITEM (on_save_as1_activate, NULL),
-        { GNOME_APP_UI_ITEM, "Save _All", "Save all open unsaved files", on_saveall1_activate, NULL,NULL, 0, 0, 'a', GDK_SHIFT_MASK | GDK_MOD1_MASK },
-        { GNOME_APP_UI_ITEM, "_Rename", "Rename the current file 'on-the-fly'", on_rename1_activate, NULL,NULL, 0, 0, 'r', GDK_SHIFT_MASK | GDK_MOD1_MASK },
+        { GNOME_APP_UI_ITEM, N_("Save _All"), N_("Save all open unsaved files"), on_saveall1_activate, NULL,NULL, 0, 0, 'a', GDK_SHIFT_MASK | GDK_MOD1_MASK },
+        { GNOME_APP_UI_ITEM, N_("_Rename"), N_("Rename the current file 'on-the-fly'"), on_rename1_activate, NULL,NULL, 0, 0, 'r', GDK_SHIFT_MASK | GDK_MOD1_MASK },
         GNOMEUIINFO_MENU_CLOSE_ITEM (on_close1_activate, NULL),
         GNOMEUIINFO_SEPARATOR,
         //  GNOMEUIINFO_MENU_PROPERTIES_ITEM (on_properties1_activate, NULL),
@@ -126,8 +126,8 @@ static GnomeUIInfo edit1_menu_uiinfo[] =
         GNOMEUIINFO_MENU_FIND_ITEM (on_find1_activate, NULL),
         GNOMEUIINFO_MENU_REPLACE_ITEM (on_replace1_activate, NULL),
         GNOMEUIINFO_SEPARATOR,
-        { GNOME_APP_UI_ITEM, "_Indent block", "Indent the currently selected block", block_indent, NULL,NULL, 0, 0, 'i', GDK_SHIFT_MASK | GDK_MOD1_MASK },
-        { GNOME_APP_UI_ITEM, "_Unindent block", "Unindent the currently selected block", block_unindent, NULL,NULL, 0, 0, 'i', GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK},
+        { GNOME_APP_UI_ITEM, N_("_Indent block"), N_("Indent the currently selected block"), block_indent, NULL,NULL, 0, 0, 'i', GDK_SHIFT_MASK | GDK_MOD1_MASK },
+        { GNOME_APP_UI_ITEM, N_("_Unindent block"), N_("Unindent the currently selected block"), block_unindent, NULL,NULL, 0, 0, 'i', GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK},
         //  GNOMEUIINFO_SEPARATOR,
         GNOMEUIINFO_MENU_PREFERENCES_ITEM (on_preferences1_activate, NULL),
         GNOMEUIINFO_END
@@ -141,34 +141,34 @@ static GnomeUIInfo edit1_menu_uiinfo[] =
 
 static GnomeUIInfo force1_menu_uiinfo[] =
     {
-        { GNOME_APP_UI_ITEM, "PHP/HTML/XML", "Force syntax highlighting to PHP/HTML/XML mode", force_php, NULL,NULL, 0, 0, 0, 0 },
-        { GNOME_APP_UI_ITEM, "CSS", "Force syntax highlighting to CSS mode", force_css, NULL,NULL, 0, 0, 0, 0 },
-        { GNOME_APP_UI_ITEM, "SQL", "Force syntax highlighting to SQL mode", force_sql, NULL,NULL, 0, 0, 0, 0 },
-        { GNOME_APP_UI_ITEM, "C/C++", "Force syntax highlighting to C/C++ mode", force_cxx, NULL,NULL, 0, 0, 0, 0 },
-        { GNOME_APP_UI_ITEM, "Perl", "Force syntax highlighting to Perl mode", force_perl, NULL,NULL, 0, 0, 0, 0 },
-        { GNOME_APP_UI_ITEM, "Python", "Force syntax highlighting to Python mode", force_python, NULL,NULL, 0, 0, 0, 0 },
+        { GNOME_APP_UI_ITEM, N_("PHP/HTML/XML"), N_("Force syntax highlighting to PHP/HTML/XML mode"), force_php, NULL,NULL, 0, 0, 0, 0 },
+        { GNOME_APP_UI_ITEM, N_("CSS"), N_("Force syntax highlighting to CSS mode"), force_css, NULL,NULL, 0, 0, 0, 0 },
+        { GNOME_APP_UI_ITEM, N_("SQL"), N_("Force syntax highlighting to SQL mode"), force_sql, NULL,NULL, 0, 0, 0, 0 },
+        { GNOME_APP_UI_ITEM, N_("C/C++"), N_("Force syntax highlighting to C/C++ mode"), force_cxx, NULL,NULL, 0, 0, 0, 0 },
+        { GNOME_APP_UI_ITEM, N_("Perl"), N_("Force syntax highlighting to Perl mode"), force_perl, NULL,NULL, 0, 0, 0, 0 },
+        { GNOME_APP_UI_ITEM, N_("Python"), N_("Force syntax highlighting to Python mode"), force_python, NULL,NULL, 0, 0, 0, 0 },
         GNOMEUIINFO_END
     };
 	
 static GnomeUIInfo code1_menu_uiinfo[] =
     {
-        { GNOME_APP_UI_ITEM, "_Syntax check", "Check the syntax using the PHP command line binary", syntax_check, NULL,NULL, 0, 0, GDK_F9, 0 },
-        { GNOME_APP_UI_ITEM, "_Clear syntax check", "Remove the syntax check window", syntax_check_clear, NULL,NULL, 0, 0, GDK_F9, GDK_SHIFT_MASK },
+        { GNOME_APP_UI_ITEM, N_("_Syntax check"), N_("Check the syntax using the PHP command line binary"), syntax_check, NULL,NULL, 0, 0, GDK_F9, 0 },
+        { GNOME_APP_UI_ITEM, N_("_Clear syntax check"), N_("Remove the syntax check window"), syntax_check_clear, NULL,NULL, 0, 0, GDK_F9, GDK_SHIFT_MASK },
         GNOMEUIINFO_SEPARATOR,
-        { GNOME_APP_UI_ITEM, "_Record keyboard macro start/stop", "Record keyboard actions", keyboard_macro_startstop, NULL,NULL, 0, 0, 'k', GDK_MOD1_MASK },
-        { GNOME_APP_UI_ITEM, "_Playback keyboard macro", "Playback the stored keyboard macro", keyboard_macro_playback, NULL,NULL, 0, 0, 'k', GDK_CONTROL_MASK },
+        { GNOME_APP_UI_ITEM, N_("_Record keyboard macro start/stop"), N_("Record keyboard actions"), keyboard_macro_startstop, NULL,NULL, 0, 0, 'k', GDK_MOD1_MASK },
+        { GNOME_APP_UI_ITEM, N_("_Playback keyboard macro"), N_("Playback the stored keyboard macro"), keyboard_macro_playback, NULL,NULL, 0, 0, 'k', GDK_CONTROL_MASK },
         GNOMEUIINFO_SEPARATOR,
-        { GNOME_APP_UI_ITEM, "S_how class browser", "Show class browser", classbrowser_show, NULL,NULL, 0, 0, GDK_F8, 0 },
-        { GNOME_APP_UI_ITEM, "H_ide class browser", "Hide class browser", classbrowser_hide, NULL,NULL, 0, 0, GDK_F8, GDK_SHIFT_MASK },
+        { GNOME_APP_UI_ITEM, N_("S_how/Hide class browser"), N_("Show/Hide class browser"), classbrowser_show_hide, NULL,NULL, 0, 0, GDK_F8, 0 },
+        //{ GNOME_APP_UI_ITEM, N_("H_ide class browser"), N_("Hide class browser"), classbrowser_hide, NULL,NULL, 0, 0, GDK_F8, GDK_SHIFT_MASK },
         GNOMEUIINFO_SEPARATOR,
-		GNOMEUIINFO_SUBTREE("_Force highlighting mode", force1_menu_uiinfo),
+		GNOMEUIINFO_SUBTREE(N_("_Force highlighting mode"), force1_menu_uiinfo),
         GNOMEUIINFO_END
     };
 
 
 static GnomeUIInfo help1_menu_uiinfo[] =
     {
-        { GNOME_APP_UI_ITEM, "_PHP Help", "Look for help on the currently selected function", context_help, NULL,NULL, 0, 0, GDK_F1, 0 },
+        { GNOME_APP_UI_ITEM, N_("_PHP Help"), N_("Look for help on the currently selected function"), context_help, NULL,NULL, 0, 0, GDK_F1, 0 },
         GNOMEUIINFO_MENU_ABOUT_ITEM (on_about1_activate, NULL),
         GNOMEUIINFO_END
     };
@@ -180,9 +180,8 @@ static GnomeUIInfo menubar1_uiinfo[] =
         GNOMEUIINFO_MENU_EDIT_TREE (edit1_menu_uiinfo),
         //  { GNOME_APP_UI_SUBTREE_STOCK, "_Project", NULL, project1_menu_uiinfo, NULL, NULL,
         //		(GnomeUIPixmapType) 0, NULL, 0,	(GdkModifierType) 0, NULL },
-        { GNOME_APP_UI_SUBTREE_STOCK, "_Code", NULL, code1_menu_uiinfo, NULL, NULL,
-          (GnomeUIPixmapType) 0, NULL, 0,	(GdkModifierType) 0, NULL },
-		GNOMEUIINFO_SUBTREE("_Plugins", plugin_menu),
+		GNOMEUIINFO_SUBTREE (N_("_Code"), code1_menu_uiinfo),
+		GNOMEUIINFO_SUBTREE(N_("_Plugins"), plugin_menu),
         GNOMEUIINFO_MENU_HELP_TREE (help1_menu_uiinfo),
         GNOMEUIINFO_END
     };
