@@ -107,18 +107,18 @@ void check_for_pango_fonts(void)
 
 void preferences_apply(void)
 {
-	gint root_x;
-	gint root_y;
-	gint width;
-	gint height;
-
-	root_x = gnome_config_get_int ("gPHPEdit/main_window/x=20");
-	root_y = gnome_config_get_int ("gPHPEdit/main_window/y=20");
-	width = gnome_config_get_int ("gPHPEdit/main_window/width=400");
-	height = gnome_config_get_int ("gPHPEdit/main_window/height=400");
-
-	gtk_window_move(GTK_WINDOW(main_window.window), root_x, root_y);
-	gtk_window_set_default_size(GTK_WINDOW(main_window.window), width, height);
+	preferences.left   = gnome_config_get_int ("gPHPEdit/main_window/x=20");
+	preferences.top    = gnome_config_get_int ("gPHPEdit/main_window/y=20");
+	preferences.width  = gnome_config_get_int ("gPHPEdit/main_window/width=400");
+	preferences.height = gnome_config_get_int ("gPHPEdit/main_window/height=400");
+	preferences.maximized = gnome_config_get_bool ("gPHPEdit/main_window/maximized=false");
+ 
+	gtk_window_move(GTK_WINDOW(main_window.window), preferences.left, preferences.top);
+	gtk_window_set_default_size(GTK_WINDOW(main_window.window), preferences.width, preferences.height);
+ 	
+	if (preferences.maximized) {
+ 		gtk_window_maximize(GTK_WINDOW(main_window.window));
+	}
 }
 
 void preferences_load(void)
@@ -128,7 +128,7 @@ void preferences_load(void)
 	preferences.set_sel_back = gnome_config_get_int ("gPHPEdit/default_style/selection=11250603");
 	preferences.marker_back = gnome_config_get_int ("gPHPEdit/default_style/bookmark=15908608");
 	preferences.php_binary_location = gnome_config_get_string ("gPHPEdit/locations/php_binary=php");
-	preferences.shared_source_location = gnome_config_get_string ("gPHPEdit/locations/shared_source=/home/shares/websites/iaCodeBase/");
+	preferences.shared_source_location = gnome_config_get_string ("gPHPEdit/locations/shared_source=");
 	preferences.indentation_size = gnome_config_get_int ("gPHPEdit/defaults/indentationsize=4");
 	preferences.tab_size = gnome_config_get_int ("gPHPEdit/defaults/tabsize=4");
 	preferences.auto_complete_delay = gnome_config_get_int ("gPHPEdit/defaults/auto_complete_delay=500");
@@ -499,34 +499,26 @@ void save_classbrowser_position(void)
 	}
 }
 
-void main_window_size_save_details(gint x, gint y, gint width, gint height)
+void main_window_size_save_details()
 {
-	gnome_config_set_int ("gPHPEdit/main_window/x", x);
-	gnome_config_set_int ("gPHPEdit/main_window/y", y);
-	gnome_config_set_int ("gPHPEdit/main_window/width", width);
-	gnome_config_set_int ("gPHPEdit/main_window/height", height);
-	//g_print("X:%d\nY:%d\nW:%d\nH:%d\n", x, y, width, height);
-}
+	preferences.maximized = gnome_config_get_bool ("gPHPEdit/main_window/maximized=false");
+	
+	if (!preferences.maximized) {
+		gtk_window_get_position(GTK_WINDOW(main_window.window), &preferences.left, &preferences.top);
+		gtk_window_get_size(GTK_WINDOW(main_window.window), &preferences.width, &preferences.height);
 
-
-void main_window_size_save(void)
-{
-	gint root_x;
-	gint root_y;
-	gint width;
-	gint height;
-
-	gtk_window_get_position(GTK_WINDOW(main_window.window), &root_x, &root_y);
-	gtk_window_get_size(GTK_WINDOW(main_window.window), &width, &height);
-	main_window_size_save_details(root_x, root_y, width, height);
-	gnome_config_set_int("gPHPEdit/main_window/classbrowser_size", gtk_paned_get_position(GTK_PANED(main_window.main_horizontal_pane)));
+		gnome_config_set_int ("gPHPEdit/main_window/x", preferences.left);
+		gnome_config_set_int ("gPHPEdit/main_window/y", preferences.top);
+		gnome_config_set_int ("gPHPEdit/main_window/width", preferences.width);
+		gnome_config_set_int ("gPHPEdit/main_window/height", preferences.height);
+	
+		gnome_config_sync();
+	}
 }
 
 
 void preferences_save(void)
 {
-	//main_window_size_save();
-
 	gnome_config_set_string ("gPHPEdit/default_style/font", preferences.default_font);
 	gnome_config_set_int ("gPHPEdit/default_style/fore", preferences.default_fore);
 	gnome_config_set_int ("gPHPEdit/default_style/back", preferences.default_back);
