@@ -36,7 +36,7 @@ typedef struct
 	gint height;
 	gint left;
 	gint top;
-	gint maximised;
+	gboolean maximized;
 
 	// Default settings
 	gint set_sel_back;
@@ -247,112 +247,112 @@ typedef struct
 	gboolean php_comment_line_bold;
 	gboolean php_comment_line_italic;
 
-	guint css_tag_back;
+	gint css_tag_back;
 	gchar *css_tag_font;
-	guint css_tag_fore;
+	gint css_tag_fore;
 	gint css_tag_size;
 	gboolean css_tag_bold;
 	gboolean css_tag_italic;
-	guint css_class_fore;
+	gint css_class_fore;
 	gchar *css_class_font;
-	guint css_class_back;
+	gint css_class_back;
 	gint css_class_size;
 	gboolean css_class_bold;
 	gboolean css_class_italic;
-	guint css_pseudoclass_back;
+	gint css_pseudoclass_back;
 	gchar *css_pseudoclass_font;
-	guint css_pseudoclass_fore;
+	gint css_pseudoclass_fore;
 	gint css_pseudoclass_size;
 	gboolean css_pseudoclass_bold;
 	gboolean css_pseudoclass_italic;
-	guint css_unknown_pseudoclass_fore;
+	gint css_unknown_pseudoclass_fore;
 	gchar *css_unknown_pseudoclass_font;
-	guint css_unknown_pseudoclass_back;
+	gint css_unknown_pseudoclass_back;
 	gint css_unknown_pseudoclass_size;
 	gboolean css_unknown_pseudoclass_bold;
 	gboolean css_unknown_pseudoclass_italic;
-	guint css_operator_fore;
+	gint css_operator_fore;
 	gchar *css_operator_font;
-	guint css_operator_back;
+	gint css_operator_back;
 	gint css_operator_size;
 	gboolean css_operator_bold;
 	gboolean css_operator_italic;
-	guint css_identifier_fore;
+	gint css_identifier_fore;
 	gchar *css_identifier_font;
-	guint css_identifier_back;
+	gint css_identifier_back;
 	gint css_identifier_size;
 	gboolean css_identifier_bold;
 	gboolean css_identifier_italic;
-	guint css_unknown_identifier_fore;
+	gint css_unknown_identifier_fore;
 	gchar *css_unknown_identifier_font;
-	guint css_unknown_identifier_back;
+	gint css_unknown_identifier_back;
 	gint css_unknown_identifier_size;
 	gboolean css_unknown_identifier_bold;
 	gboolean css_unknown_identifier_italic;
-	guint css_value_fore;
+	gint css_value_fore;
 	gchar *css_value_font;
-	guint css_value_back;
+	gint css_value_back;
 	gint css_value_size;
 	gboolean css_value_bold;
 	gboolean css_value_italic;
-	guint css_comment_fore;
+	gint css_comment_fore;
 	gchar *css_comment_font;
-	guint css_comment_back;
+	gint css_comment_back;
 	gint css_comment_size;
 	gboolean css_comment_bold;
 	gboolean css_comment_italic;
 	gchar *css_id_font;
-	guint css_id_fore;
-	guint css_id_back;
+	gint css_id_fore;
+	gint css_id_back;
 	gint css_id_size;
 	gboolean css_id_bold;
 	gboolean css_id_italic;
 	gchar *css_important_font;
-	guint css_important_fore;
-	guint css_important_back;
+	gint css_important_fore;
+	gint css_important_back;
 	gint css_important_size;
 	gboolean css_important_bold;
 	gboolean css_important_italic;
-	guint css_directive_fore;
+	gint css_directive_fore;
 	gchar *css_directive_font;
-	guint css_directive_back;
+	gint css_directive_back;
 	gint css_directive_size;
 	gboolean css_directive_bold;
 	gboolean css_directive_italic;
 	
-	guint sql_word_back;
+	gint sql_word_back;
 	gchar *sql_word_font;
-	guint sql_word_fore;
+	gint sql_word_fore;
 	gint sql_word_size;
 	gboolean sql_word_bold;
 	gboolean sql_word_italic;
-	guint sql_identifier_back;
+	gint sql_identifier_back;
 	gchar *sql_identifier_font;
-	guint sql_identifier_fore;
+	gint sql_identifier_fore;
 	gint sql_identifier_size;
 	gboolean sql_identifier_bold;
 	gboolean sql_identifier_italic;
-	guint sql_number_back;
+	gint sql_number_back;
 	gchar *sql_number_font;
-	guint sql_number_fore;
+	gint sql_number_fore;
 	gint sql_number_size;
 	gboolean sql_number_bold;
 	gboolean sql_number_italic;
-	guint sql_string_back;
+	gint sql_string_back;
 	gchar *sql_string_font;
-	guint sql_string_fore;
+	gint sql_string_fore;
 	gint sql_string_size;
 	gboolean sql_string_bold;
 	gboolean sql_string_italic;
-	guint sql_operator_back;
+	gint sql_operator_back;
 	gchar *sql_operator_font;
-	guint sql_operator_fore;
+	gint sql_operator_fore;
 	gint sql_operator_size;
 	gboolean sql_operator_bold;
 	gboolean sql_operator_italic;
-	guint sql_comment_back;
+	gint sql_comment_back;
 	gchar *sql_comment_font;
-	guint sql_comment_fore;
+	gint sql_comment_fore;
 	gint sql_comment_size;
 	gboolean sql_comment_bold;
 	gboolean sql_comment_italic;
@@ -365,8 +365,9 @@ extern Preferences preferences;
 void preferences_load(void);
 void preferences_save(void);
 void preferences_show(void);
-void main_window_size_save(void);
-void main_window_size_save_details(gint x, gint y, gint width, gint height);
+//void main_window_size_save(void);
+void main_window_size_save_details();
+
 void move_classbrowser_position(void);
 void save_classbrowser_position(void);
 void preferences_apply(void);
