@@ -596,7 +596,7 @@ void change_size_global_callback(gint reply,gpointer data)
 	gint fontsize;
 
 	//g_print("change_size_global: %d\n", reply);
-	if (reply==0) {
+	if (reply==GTK_RESPONSE_YES) {
 		fontsize = (gulong)data; // was (gint)
 		
 		temp_preferences.default_size = fontsize;
@@ -658,7 +658,7 @@ void get_control_values_to_highlight(gchar *setting_name, gchar **fontname, gint
 	guint8 red, blue, green, alpha;
 	GtkWidget *dialog;
 	GString *message;
-	gulong newfontsize; // was gint
+	gint newfontsize; // Back to being a gint, g_string_printf complains
 	gint result;
 
 	if (preferences_dialog.changing_highlight_element) {
@@ -1079,6 +1079,11 @@ void on_php_file_extensions_changed (GtkEntry *entry, gpointer user_data)
 	temp_preferences.php_file_extensions = g_strdup(gtk_entry_get_text(entry));
 }
 
+void on_shared_source_changed (GtkEntry *entry, gpointer user_data)
+{
+	temp_preferences.shared_source_location = g_strdup(gtk_entry_get_text(entry));
+}
+
 
 void update_template_display(gchar *template)
 {
@@ -1517,7 +1522,7 @@ void preferences_dialog_create (void)
                       NULL);
 	g_list_free (comboitems);
 	
-	preferences_dialog.label44 = gtk_label_new ("Font");
+	preferences_dialog.label44 = gtk_label_new (_("Font"));
 	gtk_widget_show (preferences_dialog.label44);
 	gtk_frame_set_label_widget (GTK_FRAME (preferences_dialog.frame4), preferences_dialog.label44);
 	
@@ -1597,7 +1602,22 @@ void preferences_dialog_create (void)
 	gtk_entry_set_text(GTK_ENTRY(preferences_dialog.file_extensions), temp_preferences.php_file_extensions);
 	gtk_signal_connect(GTK_OBJECT(preferences_dialog.file_extensions),
     		"changed", GTK_SIGNAL_FUNC(on_php_file_extensions_changed),NULL);
+
+	preferences_dialog.hbox26 = gtk_hbox_new (FALSE, 0);
+	gtk_widget_show (preferences_dialog.hbox26);
+	gtk_box_pack_start (GTK_BOX (preferences_dialog.vbox7), preferences_dialog.hbox26, FALSE, TRUE, 8);
 	
+	preferences_dialog.label45 = gtk_label_new (_("Shared library path(s):"));
+	gtk_widget_show (preferences_dialog.label45);
+	gtk_box_pack_start (GTK_BOX (preferences_dialog.hbox26), preferences_dialog.label45, FALSE, FALSE, 8);
+	
+	preferences_dialog.shared_source = gtk_entry_new ();
+	gtk_widget_show (preferences_dialog.shared_source);
+	gtk_box_pack_start (GTK_BOX (preferences_dialog.hbox26), preferences_dialog.shared_source, TRUE, TRUE, 0);
+	gtk_entry_set_text(GTK_ENTRY(preferences_dialog.shared_source), temp_preferences.shared_source_location);
+	gtk_signal_connect(GTK_OBJECT(preferences_dialog.shared_source),
+    		"changed", GTK_SIGNAL_FUNC(on_shared_source_changed),NULL);
+
 	preferences_dialog.hbox19 = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (preferences_dialog.hbox19);
 	gtk_box_pack_start (GTK_BOX (preferences_dialog.vbox7), preferences_dialog.hbox19, FALSE, TRUE, 8);
@@ -1666,7 +1686,7 @@ void preferences_dialog_create (void)
 	gtk_container_set_border_width (GTK_CONTAINER (preferences_dialog.edit_template_button), 2);
 	gtk_signal_connect (GTK_OBJECT (preferences_dialog.edit_template_button), "clicked", GTK_SIGNAL_FUNC (edit_template_clicked), NULL);
 	
-	preferences_dialog.delete_template_button = gtk_button_new_with_mnemonic (("Delete"));
+	preferences_dialog.delete_template_button = gtk_button_new_with_mnemonic (_("Delete"));
 	gtk_widget_show (preferences_dialog.delete_template_button);
 	gtk_box_pack_start (GTK_BOX (preferences_dialog.vbox9), preferences_dialog.delete_template_button, FALSE, FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (preferences_dialog.delete_template_button), 2);
