@@ -39,6 +39,7 @@ typedef struct
   GtkWidget *notebook1;
   GtkWidget *vbox6;
   GtkWidget *hbox14;
+  GtkWidget *hbox26;
   GtkWidget *label32;
   GtkWidget *tab_size;
   GtkWidget *tabs_not_spaces;
@@ -75,6 +76,7 @@ typedef struct
   GtkWidget *size_combo;
   GtkWidget *combo_entry3;
   GtkWidget *label44;
+  GtkWidget *label45;
   GtkWidget *frame1;
   GtkWidget *element_combo;
   GtkWidget *combo_entry4;
@@ -88,6 +90,7 @@ typedef struct
   GtkWidget *hbox18;
   GtkWidget *label36;
   GtkWidget *file_extensions;
+  GtkWidget *shared_source;
   GtkWidget *hbox19;
   GtkWidget *label37;
   GtkWidget *delay;
