@@ -33,19 +33,17 @@ gchar *run_php_lint(gchar *command_line)
 {
 	gboolean result;
 	gchar *stdout;
-	gchar *stderr;
 	gint exit_status;
 	GError *error;
 
 	error = NULL;
 
 	result = g_spawn_command_line_sync (command_line,
-	                                    &stdout, &stderr, &exit_status, &error);
+	                                    &stdout, NULL, &exit_status, &error);
 
 	if (!result) {
 		return NULL;
 	}
-	g_free(stderr);
 	return stdout;
 }
 
@@ -63,19 +61,19 @@ void syntax_add_lines(gchar *output)
 
 	first_error = 0;
 	copy = output;
-	
-	while ((token = strtok(copy, "\r\n"))) {
+
+	while ((token = strtok(copy, "\n"))) {
 		if ((strncmp(token, "PHP Warning:  ", MIN(strlen(token), 14))!=0) && (strncmp(token, "Content-type", MIN(strlen(token), 12))!=0)) { 
 			gtk_list_store_append (main_window.lint_store, &iter);
 			gtk_list_store_set (main_window.lint_store, &iter, 0, token, -1);
 	
 			line_number = strrchr(token, ' ');
 			line_number++;
-			if (!first_error) {
-				first_error = line_number;
-			}
 	
 			if (atoi(line_number)>0) {
+				if (!first_error) {
+					first_error = line_number;
+				}
 				indent = gtk_scintilla_get_line_indentation(GTK_SCINTILLA(main_window.current_editor->scintilla), atoi(line_number)-1);
 	
 				line_start = gtk_scintilla_position_from_line(GTK_SCINTILLA(main_window.current_editor->scintilla), atoi(line_number)-1);
@@ -86,11 +84,16 @@ void syntax_add_lines(gchar *output)
 				gtk_scintilla_start_styling(GTK_SCINTILLA(main_window.current_editor->scintilla), line_start, 128);
 				gtk_scintilla_set_styling(GTK_SCINTILLA(main_window.current_editor->scintilla), line_end-line_start, INDIC2_MASK);
 			}
+			else {
+				g_print("Line number is 0\n");
+			}
 		}
 		copy = NULL;
 	}
 
-	goto_line(first_error);
+	if (first_error) {
+		goto_line(first_error);
+	}
 }
 
 
@@ -111,7 +114,7 @@ GString *save_as_temp_file(void)
 		write_buffer = g_malloc0(text_length+1); // Include terminating null
 
 		if (write_buffer == NULL) {
-			g_warning ("%s", "Cannot allocate write buffer");
+			g_warning ("%s", _("Cannot allocate write buffer"));
 			return NULL;
 		}
 		
@@ -191,7 +194,7 @@ void syntax_check_run(void)
 		main_window.lint_store = gtk_list_store_new (1, G_TYPE_STRING);
 		gtk_list_store_clear(main_window.lint_store);
 		gtk_list_store_append (main_window.lint_store, &iter);
-		gtk_list_store_set (main_window.lint_store, &iter, 0, "You don't have any files open to check\n", -1);
+		gtk_list_store_set (main_window.lint_store, &iter, 0, _("You don't have any files open to check\n"), -1);
 		gtk_tree_view_set_model(GTK_TREE_VIEW(main_window.lint_view), GTK_TREE_MODEL(main_window.lint_store));
 	}
 }
