@@ -46,7 +46,8 @@ guint completion_timer_id;
 gboolean completion_timer_set;
 guint calltip_timer_id;
 gboolean calltip_timer_set;
-
+guint gotoline_after_reload = 0;
+guint gotoline_after_create_tab = 0;
 
 static void save_point_reached(GtkWidget *w);
 static void save_point_left(GtkWidget *w);
@@ -69,7 +70,7 @@ void debug_dump_editors(void)
 		
 		g_print("Editor number    :%d\n", editor_number);
 		g_print("Scintilla widget :%p\n", editor->scintilla);
-		g_print("Scintilla lexer :%p\n", gtk_scintilla_get_lexer(GTK_SCINTILLA(editor->scintilla)));
+		g_print("Scintilla lexer  :%d\n", gtk_scintilla_get_lexer(GTK_SCINTILLA(editor->scintilla)));
 		g_print("Scintilla ID     :%d\n", editor->scintilla_id);
 		g_print("File mtime       :%d\n", editor->file_mtime);
 		g_print("File shortname   :%s\n", editor->short_filename);
@@ -97,6 +98,8 @@ void tab_set_general_scintilla_properties(Editor *editor)
 	gtk_signal_connect (GTK_OBJECT (editor->scintilla), "save_point_left", GTK_SIGNAL_FUNC (save_point_left), NULL);
 	gtk_signal_connect (GTK_OBJECT (editor->scintilla), "macro_record", GTK_SIGNAL_FUNC (macro_record), NULL);
 
+	gtk_scintilla_set_sel_back(GTK_SCINTILLA(editor->scintilla), 1, 13434879);
+
 	tab_set_configured_scintilla_properties(GTK_SCINTILLA(editor->scintilla), preferences);
 	gtk_widget_show (editor->scintilla);
 }
@@ -201,10 +204,10 @@ void report_vfs_error(gchar *name, gchar *desc, GnomeVFSResult result, GtkWindow
 	gchar *err_title, *err_message;
 	
 	if (name) {
-		err_title = g_strdup_printf("File access error:\n %s: ", name);
+		err_title = g_strdup_printf(_("File access error:\n %s: "), name);
 	}
 	else {
-		err_title = g_strdup_printf("File access error: \n");
+		err_title = g_strdup_printf(_("File access error: \n"));
 	}
 	
 	if (result < GNOME_VFS_NUM_ERRORS) {
@@ -221,10 +224,15 @@ void report_vfs_error(gchar *name, gchar *desc, GnomeVFSResult result, GtkWindow
 	g_free(err_message);
 }
 
-int gnome_vfs_print_error (GnomeVFSResult result, char *uri_string)
+void tab_file_closed(GnomeVFSAsyncHandle *fd, GnomeVFSResult result, gpointer li_ptr)
 {
-  report_vfs_error(uri_string, NULL, result, GTK_WINDOW(main_window.window));
-  return 1;
+	//Editor *editor = (Editor *)li_ptr;
+
+	if (result != GNOME_VFS_OK) {
+		g_print(_("VFS Error: %s\n"), gnome_vfs_result_to_string (result));
+		//gnome_vfs_print_error(result, editor->filename->str);
+	}
+	session_save();
 }
 
 void tab_file_write(GnomeVFSAsyncHandle *fd, GnomeVFSResult result, gconstpointer buffer, GnomeVFSFileSize bytes_requested, GnomeVFSFileSize bytes_received, gpointer li_ptr)
@@ -232,13 +240,16 @@ void tab_file_write(GnomeVFSAsyncHandle *fd, GnomeVFSResult result, gconstpointe
   	Editor *editor = (Editor *)li_ptr;
 	
 	if (result != GNOME_VFS_OK) {
-		gnome_vfs_print_error(result, editor->filename->str);
+		g_print(_("VFS Error: %s\n"), gnome_vfs_result_to_string (result));
+		//gnome_vfs_print_error(result, editor->filename->str);
 		return;
 	}
-
+	
+	gnome_vfs_async_close (fd, tab_file_closed, li_ptr);
 	gtk_scintilla_set_save_point (GTK_SCINTILLA(editor->scintilla));
 	register_file_opened(editor->filename->str);
 	classbrowser_update();
+	session_save();
 }
 
 void tab_file_save_opened(GnomeVFSAsyncHandle *fd, GnomeVFSResult result, gpointer li_ptr)
@@ -248,11 +259,12 @@ void tab_file_save_opened(GnomeVFSAsyncHandle *fd, GnomeVFSResult result, gpoint
 	GError *error = NULL;
 	gchar *converted_text = NULL;
 	gsize utf8_size; // was guint
-	GnomeVFSFileSize bytes_written;
-	Editor *editor = (Editor *)li_ptr;
+	//GnomeVFSFileSize bytes_written;
+	//Editor *editor = (Editor *)li_ptr;
 	
 	if (result != GNOME_VFS_OK) {
-		gnome_vfs_print_error(result, editor->filename->str);
+ 		g_print(_("VFS Error: %s\n"), gnome_vfs_result_to_string (result));
+		//gnome_vfs_print_error(result, editor->filename->str);
 		return;
 	}
 
@@ -261,7 +273,7 @@ void tab_file_save_opened(GnomeVFSAsyncHandle *fd, GnomeVFSResult result, gpoint
 	write_buffer = g_malloc0(text_length+1); // Include terminating null
 
 	if (write_buffer == NULL) {
-		g_warning ("%s", "Cannot allocate write buffer");
+		g_warning ("%s", _("Cannot allocate write buffer"));
 		return;
 	}
 
@@ -271,7 +283,7 @@ void tab_file_save_opened(GnomeVFSAsyncHandle *fd, GnomeVFSResult result, gpoint
 	if (main_window.current_editor->converted_to_utf8) {
 		converted_text = g_locale_from_utf8(write_buffer, text_length, NULL, &utf8_size, &error);
 		if (error != NULL) {
-			g_print("UTF-8 Error: %s\n", error->message);
+			g_print(_("UTF-8 Error: %s\n"), error->message);
 			g_error_free(error);			
 		}
 		else {
@@ -286,15 +298,6 @@ void tab_file_save_opened(GnomeVFSAsyncHandle *fd, GnomeVFSResult result, gpoint
 	//g_free (write_buffer);
 }
 
-void tab_file_closed(GnomeVFSAsyncHandle *fd, GnomeVFSResult result, gpointer li_ptr)
-{
-	Editor *editor = (Editor *)li_ptr;
-
-	if (result != GNOME_VFS_OK) {
-		gnome_vfs_print_error(result, editor->filename->str);
-	}
-}
-
 void tab_validate_buffer_and_insert(gpointer buffer, Editor *editor)
 {
 	gchar *converted_text;
@@ -311,12 +314,12 @@ void tab_validate_buffer_and_insert(gpointer buffer, Editor *editor)
 		// converted_text = g_convert(buffer, nchars, "UTF-8", "ISO-8859-15", NULL, &utf8_size, &error);
 		converted_text = g_locale_to_utf8(buffer, editor->file_size, NULL, &utf8_size, &error);
 		if (error != NULL) {
-			g_print("gPHPEdit UTF-8 Error: %s\n", error->message);
+			g_print(_("gPHPEdit UTF-8 Error: %s\n"), error->message);
 			g_error_free(error);
 			gtk_scintilla_add_text(GTK_SCINTILLA (editor->scintilla), editor->file_size, buffer);
 		}
 		else {
-			g_print("Converted to UTF-8 size: %d\n", utf8_size);
+			g_print(_("Converted to UTF-8 size: %d\n"), utf8_size);
 			gtk_scintilla_add_text(GTK_SCINTILLA (editor->scintilla), utf8_size, converted_text);
 			g_free(converted_text);
 			editor->converted_to_utf8 = TRUE;
@@ -339,7 +342,8 @@ void tab_file_read(GnomeVFSAsyncHandle *fd, GnomeVFSResult result, gpointer buff
 	Editor *editor = (Editor *)li_ptr;
 
 	if ((result != GNOME_VFS_OK) && (result != GNOME_VFS_ERROR_EOF)) {
-		gnome_vfs_print_error(result, editor->filename->str);
+		g_print(_("VFS Error: %s\n"), gnome_vfs_result_to_string (result));
+		//gnome_vfs_print_error(result, editor->filename->str);
 		return;
 	}
 
@@ -353,6 +357,11 @@ void tab_file_read(GnomeVFSAsyncHandle *fd, GnomeVFSResult result, gpointer buff
 	
 	g_free(buffer);
 	gnome_vfs_async_close(fd, tab_file_closed, li_ptr);
+	if (gotoline_after_reload) {
+		goto_line_int(gotoline_after_reload);
+		gotoline_after_reload = 0;
+	}
+	tab_check_php_file(editor);
 }
 
 void tab_file_opened(GnomeVFSAsyncHandle *fd, GnomeVFSResult result, gpointer li_ptr)
@@ -361,7 +370,8 @@ void tab_file_opened(GnomeVFSAsyncHandle *fd, GnomeVFSResult result, gpointer li
 	Editor *editor = (Editor *)li_ptr;
 	
 	if (result != GNOME_VFS_OK) {
-		gnome_vfs_print_error(result, editor->filename->str);
+		g_print(_("VFS Error: %s\n"), gnome_vfs_result_to_string (result));
+		//gnome_vfs_print_error(result, editor->filename->str);
 		return;
 	}
 	
@@ -384,7 +394,8 @@ void tab_file_opened(GnomeVFSAsyncHandle *fd, GnomeVFSResult result, gpointer li
 	result = gnome_vfs_get_file_info(editor->filename->str, file_stats, GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
 	if (result != GNOME_VFS_OK) {
 		// Print error and return if no
-		gnome_vfs_print_error(result, editor->filename->str);
+		g_print(_("VFS Error: %s\n"), gnome_vfs_result_to_string (result));
+		//gnome_vfs_print_error(result, editor->filename->str);
 		return;
 	}
 	
@@ -428,7 +439,7 @@ void tab_help_load_file(Editor *editor, GString *filename)
  
 	if (stat (filename->str, &st) != 0)
 	{
-		g_warning ("Could not stat the file %s", filename->str);
+		g_warning (_("Could not stat the file %s"), filename->str);
 		//die();
 	}
 	size = st.st_size;
@@ -437,7 +448,7 @@ void tab_help_load_file(Editor *editor, GString *filename)
 	if (buffer == NULL && size != 0)
 	{
 		// This is funny in unix, but never hurts 
-		g_warning ("This file is too big. Unable to allocate memory.");
+		g_warning (_("This file is too big. Unable to allocate memory."));
 		//die();
 	}
 	fp = fopen (filename->str, "rb");
@@ -450,7 +461,7 @@ void tab_help_load_file(Editor *editor, GString *filename)
 	// Crude way of loading, but faster
 	nchars = fread (buffer, 1, size, fp);
 	
-	if (size != nchars) g_warning ("File size and loaded size not matching");
+	if (size != nchars) g_warning (_("File size and loaded size not matching"));
 	
 	html_document_clear(editor->help_document);
 	html_document_open_stream(editor->help_document, "text/html");
@@ -539,6 +550,15 @@ GString *tab_help_find_helpfile(gchar *command)
 	if (long_filename)
 		return long_filename;
 	long_filename = tab_help_try_filename("/usr/share/doc/phpdoc/html/", command, NULL);
+	if (long_filename)
+		return long_filename;
+	long_filename = tab_help_try_filename("/usr/share/doc/php-doc/html/function.", command, ".html");
+	if (long_filename)
+		return long_filename;
+	long_filename = tab_help_try_filename("/usr/share/doc/php-doc/html/ref.", command, ".html");
+	if (long_filename)
+		return long_filename;
+	long_filename = tab_help_try_filename("/usr/share/doc/php-doc/html/", command, NULL);
 	if (long_filename)
 		return long_filename;
 
@@ -573,7 +593,7 @@ GString *tab_help_find_helpfile(gchar *command)
 	if (long_filename)
 		return long_filename;
 
-	g_print("Help for function not found: %s\n", command);
+	g_print(_("Help for function not found: %s\n"), command);
 	
 	return NULL;
 }
@@ -593,7 +613,7 @@ static void tab_help_link_clicked(GObject *obj, const gchar *url)
 		g_string_free(editor->filename, TRUE);
 		
 		editor->filename = g_string_new(filename->str);
-		editor->filename = g_string_prepend(editor->filename, "Help: ");
+		editor->filename = g_string_prepend(editor->filename, _("Help: "));
 
 		editor->short_filename = editor->filename->str;
 		
@@ -611,7 +631,7 @@ gboolean tab_create_help(Editor *editor, GString *filename)
 	GtkWidget *dialog;
  
 	caption = g_string_new(filename->str);
-	caption = g_string_prepend(caption, "Help: ");
+	caption = g_string_prepend(caption, _("Help: "));
 
 	long_filename = tab_help_find_helpfile(filename->str);
 	if (!long_filename) {
@@ -699,7 +719,64 @@ gint yes_no_dialog (gchar *title, gchar *message)
 	return button;
 }
 
-gboolean is_php_file(gchar *filename)
+gboolean is_php_file(Editor *editor)
+{
+	// New style function for configuration of what constitutes a PHP file
+	gchar *file_extension;
+	gchar **php_file_extensions;
+	gboolean is_php = FALSE;
+	gint i;
+	gchar *buffer = NULL;
+	gsize text_length;
+	gchar **lines;
+	gchar *filename;
+
+	filename = editor->filename->str;
+
+	file_extension = strrchr(filename, '.');
+	if (file_extension) {
+		file_extension++;
+		
+		php_file_extensions = g_strsplit(preferences.php_file_extensions,",",-1);
+		
+        for (i = 0; php_file_extensions[i] != NULL; i++) {
+			if (strcmp(file_extension, php_file_extensions[i]) == 0) {
+				is_php = TRUE;
+				break;
+			}
+		}
+				
+		g_strfreev(php_file_extensions);
+	}
+	
+	if (!is_php && editor) { // If it's not recognised as a PHP file, examine the contents for <?php and #!.*php
+		
+		text_length = gtk_scintilla_get_length(GTK_SCINTILLA(editor->scintilla));
+		buffer = g_malloc0(text_length+1); // Include terminating null
+		if (buffer == NULL) {
+			g_warning ("%s", "Cannot allocate write buffer");
+			return is_php;
+		}
+		gtk_scintilla_get_text(GTK_SCINTILLA(editor->scintilla), text_length+1, buffer);
+		lines = g_strsplit(buffer, "\n", 10);
+		if (lines[0][0] == '#' && lines[0][1] == '!' && strstr(lines[0], "php") != NULL) {
+			is_php = TRUE;
+		}
+		else {
+			for (i = 0; lines[i+1] != NULL; i++) {
+				if (strstr (lines[i], "<?php") != NULL) {
+					is_php = TRUE;
+					break;
+				}
+			}
+		}
+		g_strfreev(lines);
+	}
+	
+	return is_php;
+}
+
+gboolean is_php_file_from_filename(gchar *filename)
 {
 	// New style function for configuration of what constitutes a PHP file
 	gchar *file_extension;
@@ -722,9 +799,12 @@ gboolean is_php_file(gchar *filename)
 				
 		g_strfreev(php_file_extensions);
 	}
+	
 	return is_php;
 }
 
+
+
 gboolean is_css_file(gchar *filename)
 {
 	gchar *file_extension;
@@ -836,7 +916,7 @@ void set_editor_to_python(Editor *editor)
 
 void tab_check_php_file(Editor *editor)
 {
-	if (is_php_file(editor->filename->str)) {
+	if (is_php_file(editor)) {
 		set_editor_to_php(editor);
 	}
 }
@@ -909,19 +989,20 @@ gboolean switch_to_file_or_open(gchar *filename, gint line_number)
 		if (strcmp(editor->filename->str, filename)==0) {
 			gtk_notebook_set_current_page( GTK_NOTEBOOK(main_window.notebook_editor), gtk_notebook_page_num(GTK_NOTEBOOK(main_window.notebook_editor),editor->scintilla));
 			main_window.current_editor = editor;
+			gotoline_after_reload = line_number;
 			on_reload1_activate(NULL);
-			goto_line_int(line_number);
 			return TRUE;
 		}
 	}
 
+	gotoline_after_create_tab = line_number;
 	tmp_filename = g_string_new(filename);
-	if(tab_create_new(TAB_FILE, tmp_filename))
-		goto_line_int(line_number);
+	tab_create_new(TAB_FILE, tmp_filename);
 
 	g_string_free(tmp_filename, TRUE);
 	
 	register_file_opened(filename);
+	session_save();
 	return TRUE;
 }
 
@@ -954,7 +1035,7 @@ gboolean tab_create_new(gint type, GString *filename)
 	gboolean result;
 	gboolean file_created = FALSE;
 	GnomeVFSURI *uri = NULL;
-	gchar * buffer = NULL;
+//	gchar * buffer = NULL;
 
 	if (DEBUG_MODE) { g_print("DEBUG: tab.c:tab_create_new:filename->str: %s\n", filename->str); }
 	if (filename != NULL) {
@@ -1009,7 +1090,7 @@ gboolean tab_create_new(gint type, GString *filename)
 				tab_load_file(editor);
 			}
 
-			tab_check_php_file(editor);
+			//tab_check_php_file(editor);
 			tab_check_css_file(editor);
 			tab_check_cxx_file(editor);
 			tab_check_perl_file(editor);
@@ -1041,6 +1122,11 @@ gboolean tab_create_new(gint type, GString *filename)
 		gtk_scintilla_goto_pos(GTK_SCINTILLA(editor->scintilla), 0);
 		gtk_scintilla_grab_focus(GTK_SCINTILLA(editor->scintilla));
 		main_window.current_editor = editor;
+		
+		if (gotoline_after_create_tab) {
+			goto_line_int(gotoline_after_create_tab);
+			gotoline_after_create_tab = 0;
+		}
 		editor->saved=TRUE;
 	}
 
@@ -1250,6 +1336,70 @@ void margin_clicked (GtkWidget *scintilla, gint modifiers, gint position, gint m
 }
 
 
+char *macro_message_to_string(gint message)
+{
+	switch (message) {
+		case (2170) : return "REPLACE SELECTION";
+		case (2177) : return "CLIPBOARD CUT";
+		case (2178) : return "CLIPBOARD COPY";
+		case (2179) : return "CLIPBOARD PASTE";
+		case (2180) : return "CLEAR";
+		case (2300) : return "LINE DOWN";
+		case (2301) : return "LINE DOWN EXTEND";
+		case (2302) : return "LINE UP";
+		case (2303) : return "LINE UP EXTEND";
+		case (2304) : return "CHAR LEFT";
+		case (2305) : return "CHAR LEFT EXTEND";
+		case (2306) : return "CHAR RIGHT";
+		case (2307) : return "CHAR RIGHT EXTEND";
+		case (2308) : return "WORD LEFT";
+		case (2309) : return "WORD LEFT EXTEND";
+		case (2310) : return "WORD RIGHT";
+		case (2311) : return "WORD RIGHT EXTEND";
+		case (2312) : return "HOME";
+		case (2313) : return "HOME EXTEND";
+		case (2314) : return "LINE END";
+		case (2315) : return "LINE END EXTEND";
+		case (2316) : return "DOCUMENT START";
+		case (2317) : return "DOCUMENT START EXTEND";
+		case (2318) : return "DOCUMENT END";
+		case (2319) : return "DOCUMENT END EXTEND";
+		case (2320) : return "PAGE UP";
+		case (2321) : return "PAGE UP EXTEND";
+		case (2322) : return "PAGE DOWN";
+		case (2323) : return "PAGE DOWN EXTEND";
+		default:
+			return "-- UNKNOWN --";
+		/*case (2324) : gtk_scintilla_edit_toggle_overtype(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2325) : gtk_scintilla_cancel(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2326) : gtk_scintilla_delete_back(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2327) : gtk_scintilla_tab(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2328) : gtk_scintilla_back_tab(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2329) : gtk_scintilla_new_line(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2330) : gtk_scintilla_form_feed(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2331) : gtk_scintilla_v_c_home(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2332) : gtk_scintilla_v_c_home_extend(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2333) : gtk_scintilla_zoom_in(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2334) : gtk_scintilla_zoom_out(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2335) : gtk_scintilla_del_word_left(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2336) : gtk_scintilla_del_word_right(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2337) : gtk_scintilla_line_cut(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2338) : gtk_scintilla_line_delete(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2339) : gtk_scintilla_line_transpose(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2340) : gtk_scintilla_lower_case(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2341) : gtk_scintilla_upper_case(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2342) : gtk_scintilla_line_scroll_down(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2343) : gtk_scintilla_line_scroll_up(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2344) : gtk_scintilla_delete_back_not_line(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2345) : gtk_scintilla_home_display(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2346) : gtk_scintilla_home_display_extend(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2347) : gtk_scintilla_line_end_display(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		case (2348) : gtk_scintilla_line_end_display_extend(GTK_SCINTILLA(main_window.current_editor->scintilla)); break;
+		default:
+			g_print("Unhandle keyboard macro function %d, please report to macro@gphpedit.org\n", event->message);*/
+	}
+}
+
 void macro_record (GtkWidget *scintilla, gint message, gulong wparam, glong lparam)
 {
 	Editor *editor;
@@ -1261,12 +1411,16 @@ void macro_record (GtkWidget *scintilla, gint message, gulong wparam, glong lpar
 		event->message = message;
 		event->wparam = wparam;
 		// Special handling for text inserting, duplicate inserted string
-		if (event->message == 2170) {
+		if (event->message == 2170 && editor->is_pasting) {
+			event->message = 2179;
+		}
+		else if (event->message == 2170) {
 			event->lparam = (glong) g_strdup((gchar *)lparam);
 		}
 		else {
 			event->lparam = lparam;
 		}
+		if (DEBUG_MODE) { g_print("DEBUG: tab.c:macro_record:Message: %d (%s)\n", event->message, macro_message_to_string(event->message)); }
 		
 		editor->keyboard_macro_list = g_slist_append(editor->keyboard_macro_list, event);
 	}
