@@ -71,6 +71,7 @@ typedef struct
 	GtkWidget *label;
 	GSList *keyboard_macro_list;
 	gboolean is_macro_recording;
+	gboolean is_pasting;
 	gboolean converted_to_utf8;
 	gboolean is_untitled;
 	guint current_pos;
@@ -99,7 +100,8 @@ void tab_check_perl_file(Editor *editor);
 void tab_check_python_file(Editor *editor);
 void tab_check_sql_file(Editor *editor);
 void tab_load_file(Editor *editor);
-gboolean is_php_file(gchar *filename);
+gboolean is_php_file(Editor *editor);
+gboolean is_php_file_from_filename(gchar *filename);
 gboolean switch_to_file_or_open(gchar *filename, gint line_number);
 void tab_set_configured_scintilla_properties(GtkScintilla *scintilla, Preferences prefs);
 // Probably don't need all of these declared in the .h file, but I'll remove the unnecessary ones later - AJ
@@ -122,4 +124,13 @@ gchar *convert_to_full(gchar *filename);
 void str_replace(char *Str, char ToRp, char WithC);
 void tab_file_save_opened(GnomeVFSAsyncHandle *fd, GnomeVFSResult result, gpointer li_ptr);
 
+char *macro_message_to_string(gint message);
+
+void set_editor_to_php(Editor *editor);
+void set_editor_to_css(Editor *editor);
+void set_editor_to_sql(Editor *editor);
+void set_editor_to_cxx(Editor *editor);
+void set_editor_to_perl(Editor *editor);
+void set_editor_to_python(Editor *editor);
+
 #endif
