@@ -82,7 +82,7 @@ void template_db_open(void)
   	if (!fp) {	
 		fp = template_db_create(template_filename->str);
 		if (!fp) {
-			g_print("CANNOT Create templates file: %s\n", template_filename->str);
+			g_print(_("CANNOT Create templates file: %s\n"), template_filename->str);
 			return;
 		}
 	}
@@ -140,7 +140,7 @@ void template_db_save(void)
 	  
 	fp = fopen(template_filename->str, "w");
   	if (!fp) {
-		g_print("CANNOT Create templates file: %s\n", template_filename->str);
+		g_print(_("CANNOT Create templates file: %s\n"), template_filename->str);
 		return;
 	}
 
